from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Level:
	"""Level commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def get_droop(self) -> float:
		"""SCPI: PULSe:LEVel:DROop \n
		Snippet: value: float = driver.pulse.level.get_droop() \n
		Sets the amplitude droop. \n
			:return: droop: float Range: 0 to 50
		"""
		response = self._core.io.query_str('PULSe:LEVel:DROop?')
		return Conversions.str_to_float(response)

	def set_droop(self, droop: float) -> None:
		"""SCPI: PULSe:LEVel:DROop \n
		Snippet: driver.pulse.level.set_droop(droop = 1.0) \n
		Sets the amplitude droop. \n
			:param droop: float Range: 0 to 50
		"""
		param = Conversions.decimal_value_to_str(droop)
		self._core.io.write(f'PULSe:LEVel:DROop {param}')

	def get_off(self) -> float:
		"""SCPI: PULSe:LEVel:OFF \n
		Snippet: value: float = driver.pulse.level.get_off() \n
		Sets the power during the pulse on time or the pulse off time. \n
			:return: off: No help available
		"""
		response = self._core.io.query_str('PULSe:LEVel:OFF?')
		return Conversions.str_to_float(response)

	def set_off(self, off: float) -> None:
		"""SCPI: PULSe:LEVel:OFF \n
		Snippet: driver.pulse.level.set_off(off = 1.0) \n
		Sets the power during the pulse on time or the pulse off time. \n
			:param off: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(off)
		self._core.io.write(f'PULSe:LEVel:OFF {param}')

	def get_on(self) -> float:
		"""SCPI: PULSe:LEVel:ON \n
		Snippet: value: float = driver.pulse.level.get_on() \n
		Sets the power during the pulse on time or the pulse off time. \n
			:return: on: float Range: 0 to 100
		"""
		response = self._core.io.query_str('PULSe:LEVel:ON?')
		return Conversions.str_to_float(response)

	def set_on(self, on: float) -> None:
		"""SCPI: PULSe:LEVel:ON \n
		Snippet: driver.pulse.level.set_on(on = 1.0) \n
		Sets the power during the pulse on time or the pulse off time. \n
			:param on: float Range: 0 to 100
		"""
		param = Conversions.decimal_value_to_str(on)
		self._core.io.write(f'PULSe:LEVel:ON {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Item:
	"""Item commands group definition. 56 total commands, 10 Subgroups, 11 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("item", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	@property
	def filler(self):
		"""filler commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_filler'):
			from .Filler import Filler
			self._filler = Filler(self._core, self._cmd_group)
		return self._filler

	@property
	def frequency(self):
		"""frequency commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import Frequency
			self._frequency = Frequency(self._core, self._cmd_group)
		return self._frequency

	@property
	def ipm(self):
		"""ipm commands group. 4 Sub-classes, 6 commands."""
		if not hasattr(self, '_ipm'):
			from .Ipm import Ipm
			self._ipm = Ipm(self._core, self._cmd_group)
		return self._ipm

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	@property
	def loop(self):
		"""loop commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_loop'):
			from .Loop import Loop
			self._loop = Loop(self._core, self._cmd_group)
		return self._loop

	@property
	def marker(self):
		"""marker commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import Marker
			self._marker = Marker(self._core, self._cmd_group)
		return self._marker

	@property
	def ovl(self):
		"""ovl commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ovl'):
			from .Ovl import Ovl
			self._ovl = Ovl(self._core, self._cmd_group)
		return self._ovl

	@property
	def phase(self):
		"""phase commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_phase'):
			from .Phase import Phase
			self._phase = Phase(self._core, self._cmd_group)
		return self._phase

	@property
	def rep(self):
		"""rep commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_rep'):
			from .Rep import Rep
			self._rep = Rep(self._core, self._cmd_group)
		return self._rep

	def clear(self) -> None:
		"""SCPI: SEQuence:ITEM:CLEar \n
		Snippet: driver.sequence.item.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SEQuence:ITEM:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SEQuence:ITEM:CLEar \n
		Snippet: driver.sequence.item.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SEQuence:ITEM:CLEar', opc_timeout_ms)

	def get_count(self) -> float:
		"""SCPI: SEQuence:ITEM:COUNt \n
		Snippet: value: float = driver.sequence.item.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SEQuence:ITEM:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SEQuence:ITEM:DELete \n
		Snippet: driver.sequence.item.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SEQuence:ITEM:DELete {param}')

	def get_indent(self) -> float:
		"""SCPI: SEQuence:ITEM:INDent \n
		Snippet: value: float = driver.sequence.item.get_indent() \n
		Indents the selected item rows to include it, for example, in a loop. \n
			:return: indent: float Range: 0 to 5
		"""
		response = self._core.io.query_str('SEQuence:ITEM:INDent?')
		return Conversions.str_to_float(response)

	def set_indent(self, indent: float) -> None:
		"""SCPI: SEQuence:ITEM:INDent \n
		Snippet: driver.sequence.item.set_indent(indent = 1.0) \n
		Indents the selected item rows to include it, for example, in a loop. \n
			:param indent: float Range: 0 to 5
		"""
		param = Conversions.decimal_value_to_str(indent)
		self._core.io.write(f'SEQuence:ITEM:INDent {param}')

	def get_pdelay(self) -> float:
		"""SCPI: SEQuence:ITEM:PDELay \n
		Snippet: value: float = driver.sequence.item.get_pdelay() \n
		Enables a start delay. \n
			:return: pdelay: float Range: 0 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('SEQuence:ITEM:PDELay?')
		return Conversions.str_to_float(response)

	def set_pdelay(self, pdelay: float) -> None:
		"""SCPI: SEQuence:ITEM:PDELay \n
		Snippet: driver.sequence.item.set_pdelay(pdelay = 1.0) \n
		Enables a start delay. \n
			:param pdelay: float Range: 0 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(pdelay)
		self._core.io.write(f'SEQuence:ITEM:PDELay {param}')

	def get_prf(self) -> float:
		"""SCPI: SEQuence:ITEM:PRF \n
		Snippet: value: float = driver.sequence.item.get_prf() \n
		Sets the pulse repetition interval (PRI) or the pulse repetition frequency (PRF) . \n
			:return: prf: No help available
		"""
		response = self._core.io.query_str('SEQuence:ITEM:PRF?')
		return Conversions.str_to_float(response)

	def set_prf(self, prf: float) -> None:
		"""SCPI: SEQuence:ITEM:PRF \n
		Snippet: driver.sequence.item.set_prf(prf = 1.0) \n
		Sets the pulse repetition interval (PRI) or the pulse repetition frequency (PRF) . \n
			:param prf: float Range: 0 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(prf)
		self._core.io.write(f'SEQuence:ITEM:PRF {param}')

	def get_pri(self) -> float:
		"""SCPI: SEQuence:ITEM:PRI \n
		Snippet: value: float = driver.sequence.item.get_pri() \n
		Sets the pulse repetition interval (PRI) or the pulse repetition frequency (PRF) . \n
			:return: pri: float Range: 0 to 1e+09
		"""
		response = self._core.io.query_str('SEQuence:ITEM:PRI?')
		return Conversions.str_to_float(response)

	def set_pri(self, pri: float) -> None:
		"""SCPI: SEQuence:ITEM:PRI \n
		Snippet: driver.sequence.item.set_pri(pri = 1.0) \n
		Sets the pulse repetition interval (PRI) or the pulse repetition frequency (PRF) . \n
			:param pri: float Range: 0 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(pri)
		self._core.io.write(f'SEQuence:ITEM:PRI {param}')

	def get_pulse(self) -> str:
		"""SCPI: SEQuence:ITEM:PULSe \n
		Snippet: value: str = driver.sequence.item.get_pulse() \n
		Assigns a pulse or a waveform to the selected item. Use the commands method RsPulseSeq.Pulse.
		catalog and method RsPulseSeq.Waveform.catalog to querry the available pulses and waveforms. \n
			:return: pulse: string Pulse name
		"""
		response = self._core.io.query_str('SEQuence:ITEM:PULSe?')
		return trim_str_response(response)

	def set_pulse(self, pulse: str) -> None:
		"""SCPI: SEQuence:ITEM:PULSe \n
		Snippet: driver.sequence.item.set_pulse(pulse = '1') \n
		Assigns a pulse or a waveform to the selected item. Use the commands method RsPulseSeq.Pulse.
		catalog and method RsPulseSeq.Waveform.catalog to querry the available pulses and waveforms. \n
			:param pulse: string Pulse name
		"""
		param = Conversions.value_to_quoted_str(pulse)
		self._core.io.write(f'SEQuence:ITEM:PULSe {param}')

	def get_select(self) -> float:
		"""SCPI: SEQuence:ITEM:SELect \n
		Snippet: value: float = driver.sequence.item.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SEQuence:ITEM:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SEQuence:ITEM:SELect \n
		Snippet: driver.sequence.item.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SEQuence:ITEM:SELect {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.ItemType:
		"""SCPI: SEQuence:ITEM:TYPE \n
		Snippet: value: enums.ItemType = driver.sequence.item.get_type_py() \n
		Sets the content type of the selected item. \n
			:return: type_py: PULSe| FILLer| LOOP | | OVL| SUBSequence| WAVeform
		"""
		response = self._core.io.query_str('SEQuence:ITEM:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.ItemType)

	def set_type_py(self, type_py: enums.ItemType) -> None:
		"""SCPI: SEQuence:ITEM:TYPE \n
		Snippet: driver.sequence.item.set_type_py(type_py = enums.ItemType.FILLer) \n
		Sets the content type of the selected item. \n
			:param type_py: PULSe| FILLer| LOOP | | OVL| SUBSequence| WAVeform
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.ItemType)
		self._core.io.write(f'SEQuence:ITEM:TYPE {param}')

	def get_waveform(self) -> str:
		"""SCPI: SEQuence:ITEM:WAVeform \n
		Snippet: value: str = driver.sequence.item.get_waveform() \n
		Assigns a pulse or a waveform to the selected item. Use the commands method RsPulseSeq.Pulse.
		catalog and method RsPulseSeq.Waveform.catalog to querry the available pulses and waveforms. \n
			:return: waveform: No help available
		"""
		response = self._core.io.query_str('SEQuence:ITEM:WAVeform?')
		return trim_str_response(response)

	def set_waveform(self, waveform: str) -> None:
		"""SCPI: SEQuence:ITEM:WAVeform \n
		Snippet: driver.sequence.item.set_waveform(waveform = '1') \n
		Assigns a pulse or a waveform to the selected item. Use the commands method RsPulseSeq.Pulse.
		catalog and method RsPulseSeq.Waveform.catalog to querry the available pulses and waveforms. \n
			:param waveform: string Pulse name
		"""
		param = Conversions.value_to_quoted_str(waveform)
		self._core.io.write(f'SEQuence:ITEM:WAVeform {param}')

	def clone(self) -> 'Item':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Item(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Reload:
	"""Reload commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("reload", core, parent)

	def set(self) -> None:
		"""SCPI: ADJustment:RELoad \n
		Snippet: driver.adjustment.reload.set() \n
		Reinitializes the adjustment database. You can create the level adjustment files not only automatically with the build-in
		Run Level Adjustment function but also externally (or manually) , by performing your own specific measurements. With this
		command, you can (re) load the level adjustment files, irrespectively of way they are created. \n
		"""
		self._core.io.write(f'ADJustment:RELoad')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: ADJustment:RELoad \n
		Snippet: driver.adjustment.reload.set_with_opc() \n
		Reinitializes the adjustment database. You can create the level adjustment files not only automatically with the build-in
		Run Level Adjustment function but also externally (or manually) , by performing your own specific measurements. With this
		command, you can (re) load the level adjustment files, irrespectively of way they are created. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'ADJustment:RELoad', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdw:
	"""Pdw commands group definition. 16 total commands, 2 Subgroups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdw", core, parent)

	@property
	def amMos(self):
		"""amMos commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_amMos'):
			from .AmMos import AmMos
			self._amMos = AmMos(self._core, self._cmd_group)
		return self._amMos

	@property
	def plugin(self):
		"""plugin commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_plugin'):
			from .Plugin import Plugin
			self._plugin = Plugin(self._core, self._cmd_group)
		return self._plugin

	def get_enable(self) -> bool:
		"""SCPI: SCENario:PDW:ENABle \n
		Snippet: value: bool = driver.scenario.pdw.get_enable() \n
		Enables generation of Pulse Descripter Word (PDW) reports. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:PDW:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:PDW:ENABle \n
		Snippet: driver.scenario.pdw.set_enable(enable = False) \n
		Enables generation of Pulse Descripter Word (PDW) reports. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:PDW:ENABle {param}')

	def get_host(self) -> str:
		"""SCPI: SCENario:PDW:HOST \n
		Snippet: value: str = driver.scenario.pdw.get_host() \n
		Select a connected signal generator, with all options required for the scenario, to allow reporting. \n
			:return: host: string
		"""
		response = self._core.io.query_str('SCENario:PDW:HOST?')
		return trim_str_response(response)

	def set_host(self, host: str) -> None:
		"""SCPI: SCENario:PDW:HOST \n
		Snippet: driver.scenario.pdw.set_host(host = '1') \n
		Select a connected signal generator, with all options required for the scenario, to allow reporting. \n
			:param host: string
		"""
		param = Conversions.value_to_quoted_str(host)
		self._core.io.write(f'SCENario:PDW:HOST {param}')

	def get_path(self) -> str:
		"""SCPI: SCENario:PDW:PATH \n
		Snippet: value: str = driver.scenario.pdw.get_path() \n
		Sets the target directory in that the generated report files are stored. \n
			:return: path: string
		"""
		response = self._core.io.query_str('SCENario:PDW:PATH?')
		return trim_str_response(response)

	def set_path(self, path: str) -> None:
		"""SCPI: SCENario:PDW:PATH \n
		Snippet: driver.scenario.pdw.set_path(path = '1') \n
		Sets the target directory in that the generated report files are stored. \n
			:param path: string
		"""
		param = Conversions.value_to_quoted_str(path)
		self._core.io.write(f'SCENario:PDW:PATH {param}')

	def get_template(self) -> str:
		"""SCPI: SCENario:PDW:TEMPlate \n
		Snippet: value: str = driver.scenario.pdw.get_template() \n
		Edits the selected template. \n
			:return: template: string
		"""
		response = self._core.io.query_str('SCENario:PDW:TEMPlate?')
		return trim_str_response(response)

	def set_template(self, template: str) -> None:
		"""SCPI: SCENario:PDW:TEMPlate \n
		Snippet: driver.scenario.pdw.set_template(template = '1') \n
		Edits the selected template. \n
			:param template: string
		"""
		param = Conversions.value_to_quoted_str(template)
		self._core.io.write(f'SCENario:PDW:TEMPlate {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.PwdType:
		"""SCPI: SCENario:PDW:TYPE \n
		Snippet: value: enums.PwdType = driver.scenario.pdw.get_type_py() \n
		Sets the template used be the reporting function. \n
			:return: type_py: DEFault| TEMPlate| PLUGin| AMMos
		"""
		response = self._core.io.query_str('SCENario:PDW:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.PwdType)

	def set_type_py(self, type_py: enums.PwdType) -> None:
		"""SCPI: SCENario:PDW:TYPE \n
		Snippet: driver.scenario.pdw.set_type_py(type_py = enums.PwdType.AMMos) \n
		Sets the template used be the reporting function. \n
			:param type_py: DEFault| TEMPlate| PLUGin| AMMos
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.PwdType)
		self._core.io.write(f'SCENario:PDW:TYPE {param}')

	def clone(self) -> 'Pdw':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pdw(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Volatile:
	"""Volatile commands group definition. 6 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("volatile", core, parent)

	@property
	def view(self):
		"""view commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_view'):
			from .View import View
			self._view = View(self._core, self._cmd_group)
		return self._view

	def get_sel(self) -> float:
		"""SCPI: SCENario:VOLatile:SEL \n
		Snippet: value: float = driver.scenario.volatile.get_sel() \n
		If several files are created, select the one to be visualized. \n
			:return: sel: float Subsequent number, indicating the files in the volatile memory.
		"""
		response = self._core.io.query_str('SCENario:VOLatile:SEL?')
		return Conversions.str_to_float(response)

	def set_sel(self, sel: float) -> None:
		"""SCPI: SCENario:VOLatile:SEL \n
		Snippet: driver.scenario.volatile.set_sel(sel = 1.0) \n
		If several files are created, select the one to be visualized. \n
			:param sel: float Subsequent number, indicating the files in the volatile memory.
		"""
		param = Conversions.decimal_value_to_str(sel)
		self._core.io.write(f'SCENario:VOLatile:SEL {param}')

	def clone(self) -> 'Volatile':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Volatile(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Marker:
	"""Marker commands group definition. 7 total commands, 0 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("marker", core, parent)

	def get_auto(self) -> float:
		"""SCPI: PULSe:MARKer:AUTO \n
		Snippet: value: float = driver.pulse.marker.get_auto() \n
		Enables up to four restart markers. \n
			:return: auto: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		response = self._core.io.query_str('PULSe:MARKer:AUTO?')
		return Conversions.str_to_float(response)

	def set_auto(self, auto: float) -> None:
		"""SCPI: PULSe:MARKer:AUTO \n
		Snippet: driver.pulse.marker.set_auto(auto = 1.0) \n
		Enables up to four restart markers. \n
			:param auto: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(auto)
		self._core.io.write(f'PULSe:MARKer:AUTO {param}')

	def get_fall(self) -> float:
		"""SCPI: PULSe:MARKer:FALL \n
		Snippet: value: float = driver.pulse.marker.get_fall() \n
		Enables up to four restart markers. \n
			:return: fall: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:FALL?')
		return Conversions.str_to_float(response)

	def set_fall(self, fall: float) -> None:
		"""SCPI: PULSe:MARKer:FALL \n
		Snippet: driver.pulse.marker.set_fall(fall = 1.0) \n
		Enables up to four restart markers. \n
			:param fall: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(fall)
		self._core.io.write(f'PULSe:MARKer:FALL {param}')

	def get_gate(self) -> float:
		"""SCPI: PULSe:MARKer:GATE \n
		Snippet: value: float = driver.pulse.marker.get_gate() \n
		Enables up to four restart markers. \n
			:return: gate: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:GATE?')
		return Conversions.str_to_float(response)

	def set_gate(self, gate: float) -> None:
		"""SCPI: PULSe:MARKer:GATE \n
		Snippet: driver.pulse.marker.set_gate(gate = 1.0) \n
		Enables up to four restart markers. \n
			:param gate: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(gate)
		self._core.io.write(f'PULSe:MARKer:GATE {param}')

	def get_post(self) -> float:
		"""SCPI: PULSe:MARKer:POST \n
		Snippet: value: float = driver.pulse.marker.get_post() \n
		Enables up to four restart markers. \n
			:return: post: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:POST?')
		return Conversions.str_to_float(response)

	def set_post(self, post: float) -> None:
		"""SCPI: PULSe:MARKer:POST \n
		Snippet: driver.pulse.marker.set_post(post = 1.0) \n
		Enables up to four restart markers. \n
			:param post: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(post)
		self._core.io.write(f'PULSe:MARKer:POST {param}')

	def get_pre(self) -> float:
		"""SCPI: PULSe:MARKer:PRE \n
		Snippet: value: float = driver.pulse.marker.get_pre() \n
		Enables up to four restart markers. \n
			:return: pre: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:PRE?')
		return Conversions.str_to_float(response)

	def set_pre(self, pre: float) -> None:
		"""SCPI: PULSe:MARKer:PRE \n
		Snippet: driver.pulse.marker.set_pre(pre = 1.0) \n
		Enables up to four restart markers. \n
			:param pre: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(pre)
		self._core.io.write(f'PULSe:MARKer:PRE {param}')

	def get_rise(self) -> float:
		"""SCPI: PULSe:MARKer:RISE \n
		Snippet: value: float = driver.pulse.marker.get_rise() \n
		Enables up to four restart markers. \n
			:return: rise: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:RISE?')
		return Conversions.str_to_float(response)

	def set_rise(self, rise: float) -> None:
		"""SCPI: PULSe:MARKer:RISE \n
		Snippet: driver.pulse.marker.set_rise(rise = 1.0) \n
		Enables up to four restart markers. \n
			:param rise: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(rise)
		self._core.io.write(f'PULSe:MARKer:RISE {param}')

	def get_width(self) -> float:
		"""SCPI: PULSe:MARKer:WIDTh \n
		Snippet: value: float = driver.pulse.marker.get_width() \n
		Enables up to four restart markers. \n
			:return: width: No help available
		"""
		response = self._core.io.query_str('PULSe:MARKer:WIDTh?')
		return Conversions.str_to_float(response)

	def set_width(self, width: float) -> None:
		"""SCPI: PULSe:MARKer:WIDTh \n
		Snippet: driver.pulse.marker.set_width(width = 1.0) \n
		Enables up to four restart markers. \n
			:param width: float See Table 'Setting parameter as function of the marker states'. Range: 0 to 65535
		"""
		param = Conversions.decimal_value_to_str(width)
		self._core.io.write(f'PULSe:MARKer:WIDTh {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Target:
	"""Target commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("target", core, parent)

	# noinspection PyTypeChecker
	def get_parameter(self) -> enums.TargetParam:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:PARameter \n
		Snippet: value: enums.TargetParam = driver.sequence.item.ipm.target.get_parameter() \n
		Sets the pulse parameter to that the IPM variation is assigned. \n
			:return: parameter: LEVel| RLEVel| SRATe| FREQuency| PRI| WIDTh| FALL| AMFRequency| FMDeviation| DELay| FSKDeviation| PRF| FMFRequency| CDEViation| PHASe| RISE| AMDepth | DROop| RFRequency| OVERshoot
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:TARGet:PARameter?')
		return Conversions.str_to_scalar_enum(response, enums.TargetParam)

	def set_parameter(self, parameter: enums.TargetParam) -> None:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:PARameter \n
		Snippet: driver.sequence.item.ipm.target.set_parameter(parameter = enums.TargetParam.AMDepth) \n
		Sets the pulse parameter to that the IPM variation is assigned. \n
			:param parameter: LEVel| RLEVel| SRATe| FREQuency| PRI| WIDTh| FALL| AMFRequency| FMDeviation| DELay| FSKDeviation| PRF| FMFRequency| CDEViation| PHASe| RISE| AMDepth | DROop| RFRequency| OVERshoot
		"""
		param = Conversions.enum_scalar_to_str(parameter, enums.TargetParam)
		self._core.io.write(f'SEQuence:ITEM:IPM:TARGet:PARameter {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.TargetType:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:TYPE \n
		Snippet: value: enums.TargetType = driver.sequence.item.ipm.target.get_type_py() \n
		Sets whether the profile is assigned to a parameter or to a variable. \n
			:return: type_py: PARameter| VARiable
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:TARGet:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.TargetType)

	def set_type_py(self, type_py: enums.TargetType) -> None:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:TYPE \n
		Snippet: driver.sequence.item.ipm.target.set_type_py(type_py = enums.TargetType.PARameter) \n
		Sets whether the profile is assigned to a parameter or to a variable. \n
			:param type_py: PARameter| VARiable
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.TargetType)
		self._core.io.write(f'SEQuence:ITEM:IPM:TARGet:TYPE {param}')

	def get_variable(self) -> str:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:VARiable \n
		Snippet: value: str = driver.sequence.item.ipm.target.get_variable() \n
		Sets the variable to that the variation is assigned. \n
			:return: variable: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:TARGet:VARiable?')
		return trim_str_response(response)

	def set_variable(self, variable: str) -> None:
		"""SCPI: SEQuence:ITEM:IPM:TARGet:VARiable \n
		Snippet: driver.sequence.item.ipm.target.set_variable(variable = '1') \n
		Sets the variable to that the variation is assigned. \n
			:param variable: string
		"""
		param = Conversions.value_to_quoted_str(variable)
		self._core.io.write(f'SEQuence:ITEM:IPM:TARGet:VARiable {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PlFm:
	"""PlFm commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("plFm", core, parent)

	def get_values(self) -> str:
		"""SCPI: IMPort:PDW:DATA:PLFM:VALues \n
		Snippet: value: str = driver.importPy.pdw.data.plFm.get_values() \n
		Queries the pulse parameter. \n
			:return: values: float
		"""
		response = self._core.io.query_str('IMPort:PDW:DATA:PLFM:VALues?')
		return trim_str_response(response)

	def set_values(self, values: str) -> None:
		"""SCPI: IMPort:PDW:DATA:PLFM:VALues \n
		Snippet: driver.importPy.pdw.data.plFm.set_values(values = '1') \n
		Queries the pulse parameter. \n
			:param values: No help available
		"""
		param = Conversions.value_to_quoted_str(values)
		self._core.io.write(f'IMPort:PDW:DATA:PLFM:VALues {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pulse:
	"""Pulse commands group definition. 149 total commands, 9 Subgroups, 8 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pulse", core, parent)

	@property
	def envelope(self):
		"""envelope commands group. 1 Sub-classes, 2 commands."""
		if not hasattr(self, '_envelope'):
			from .Envelope import Envelope
			self._envelope = Envelope(self._core, self._cmd_group)
		return self._envelope

	@property
	def level(self):
		"""level commands group. 0 Sub-classes, 3 commands."""
		if not hasattr(self, '_level'):
			from .Level import Level
			self._level = Level(self._core, self._cmd_group)
		return self._level

	@property
	def marker(self):
		"""marker commands group. 0 Sub-classes, 7 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import Marker
			self._marker = Marker(self._core, self._cmd_group)
		return self._marker

	@property
	def mop(self):
		"""mop commands group. 23 Sub-classes, 3 commands."""
		if not hasattr(self, '_mop'):
			from .Mop import Mop
			self._mop = Mop(self._core, self._cmd_group)
		return self._mop

	@property
	def overshoot(self):
		"""overshoot commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_overshoot'):
			from .Overshoot import Overshoot
			self._overshoot = Overshoot(self._core, self._cmd_group)
		return self._overshoot

	@property
	def preview(self):
		"""preview commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_preview'):
			from .Preview import Preview
			self._preview = Preview(self._core, self._cmd_group)
		return self._preview

	@property
	def ripple(self):
		"""ripple commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_ripple'):
			from .Ripple import Ripple
			self._ripple = Ripple(self._core, self._cmd_group)
		return self._ripple

	@property
	def time(self):
		"""time commands group. 0 Sub-classes, 6 commands."""
		if not hasattr(self, '_time'):
			from .Time import Time
			self._time = Time(self._core, self._cmd_group)
		return self._time

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePy
			self._typePy = TypePy(self._core, self._cmd_group)
		return self._typePy

	def get_catalog(self) -> str:
		"""SCPI: PULSe:CATalog \n
		Snippet: value: str = driver.pulse.get_catalog() \n
		Queries the available repository elements in the database. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('PULSe:CATalog?')
		return trim_str_response(response)

	def get_comment(self) -> str:
		"""SCPI: PULSe:COMMent \n
		Snippet: value: str = driver.pulse.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('PULSe:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: PULSe:COMMent \n
		Snippet: driver.pulse.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'PULSe:COMMent {param}')

	def set_create(self, create: str) -> None:
		"""SCPI: PULSe:CREate \n
		Snippet: driver.pulse.set_create(create = '1') \n
		Creates a repository element with the selected name. \n
			:param create: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(create)
		self._core.io.write(f'PULSe:CREate {param}')

	def get_custom(self) -> bool:
		"""SCPI: PULSe:CUSTom \n
		Snippet: value: bool = driver.pulse.get_custom() \n
		Enables the use of a custom envelope function \n
			:return: custom: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:CUSTom?')
		return Conversions.str_to_bool(response)

	def set_custom(self, custom: bool) -> None:
		"""SCPI: PULSe:CUSTom \n
		Snippet: driver.pulse.set_custom(custom = False) \n
		Enables the use of a custom envelope function \n
			:param custom: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(custom)
		self._core.io.write(f'PULSe:CUSTom {param}')

	def get_name(self) -> str:
		"""SCPI: PULSe:NAME \n
		Snippet: value: str = driver.pulse.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('PULSe:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: PULSe:NAME \n
		Snippet: driver.pulse.set_name(name = '1') \n
		Renames the selected repository element. \n
			:param name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'PULSe:NAME {param}')

	def set_remove(self, remove: str) -> None:
		"""SCPI: PULSe:REMove \n
		Snippet: driver.pulse.set_remove(remove = '1') \n
		Removes the selected element from the workspace. The element must not reference any child elements. Remove the referenced
		elements first. \n
			:param remove: No help available
		"""
		param = Conversions.value_to_quoted_str(remove)
		self._core.io.write(f'PULSe:REMove {param}')

	def get_select(self) -> str:
		"""SCPI: PULSe:SELect \n
		Snippet: value: str = driver.pulse.get_select() \n
		Selects the repository element to which the subsequent commands apply. \n
			:return: select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		response = self._core.io.query_str('PULSe:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: PULSe:SELect \n
		Snippet: driver.pulse.set_select(select = '1') \n
		Selects the repository element to which the subsequent commands apply. \n
			:param select: string Element name, as defined with the ...:CREate or ...:NAME command. To query the existing elements, use the ...:CATalog? command. For example, method RsPulseSeq.Repository.catalog.
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'PULSe:SELect {param}')

	def set_settings(self, settings: enums.PulseSetting) -> None:
		"""SCPI: PULSe:SETTings \n
		Snippet: driver.pulse.set_settings(settings = enums.PulseSetting.GENeral) \n
		Switches between the displayed settings. \n
			:param settings: TIMing| MOP| MKR| GENeral | | LEVel
		"""
		param = Conversions.enum_scalar_to_str(settings, enums.PulseSetting)
		self._core.io.write(f'PULSe:SETTings {param}')

	def clone(self) -> 'Pulse':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pulse(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trigger:
	"""Trigger commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trigger", core, parent)

	def set(self) -> None:
		"""SCPI: SCENario:TRIGger \n
		Snippet: driver.scenario.trigger.set() \n
		Triggers the scenario, if separate trigger for scenario start is enabled. See method RsPulseSeq.Program.Scenario.Xtrg.
		enable. \n
		"""
		self._core.io.write(f'SCENario:TRIGger')

	def set_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:TRIGger \n
		Snippet: driver.scenario.trigger.set_with_opc() \n
		Triggers the scenario, if separate trigger for scenario start is enabled. See method RsPulseSeq.Program.Scenario.Xtrg.
		enable. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:TRIGger', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Element:
	"""Element commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("element", core, parent)

	def get_cosine(self) -> bool:
		"""SCPI: ANTenna:MODel:CARRay:ELEMent:COSine \n
		Snippet: value: bool = driver.antenna.model.carray.element.get_cosine() \n
		Sets the characteristic of individual antenna elements. \n
			:return: cosine: ON| OFF| 1| 0 0|OFF Omnidirectional characteristic 1|ON Cosine characteristic
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:ELEMent:COSine?')
		return Conversions.str_to_bool(response)

	def set_cosine(self, cosine: bool) -> None:
		"""SCPI: ANTenna:MODel:CARRay:ELEMent:COSine \n
		Snippet: driver.antenna.model.carray.element.set_cosine(cosine = False) \n
		Sets the characteristic of individual antenna elements. \n
			:param cosine: ON| OFF| 1| 0 0|OFF Omnidirectional characteristic 1|ON Cosine characteristic
		"""
		param = Conversions.bool_to_str(cosine)
		self._core.io.write(f'ANTenna:MODel:CARRay:ELEMent:COSine {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Source:
	"""Source commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.SourceType:
		"""SCPI: SEQuence:ITEM:IPM:SOURce:TYPE \n
		Snippet: value: enums.SourceType = driver.sequence.item.ipm.source.get_type_py() \n
		Sets whether the variation is defined as a profile or as a variable. \n
			:return: type_py: PROFile| VARiable
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:SOURce:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.SourceType)

	def set_type_py(self, type_py: enums.SourceType) -> None:
		"""SCPI: SEQuence:ITEM:IPM:SOURce:TYPE \n
		Snippet: driver.sequence.item.ipm.source.set_type_py(type_py = enums.SourceType.PROFile) \n
		Sets whether the variation is defined as a profile or as a variable. \n
			:param type_py: PROFile| VARiable
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.SourceType)
		self._core.io.write(f'SEQuence:ITEM:IPM:SOURce:TYPE {param}')

	def get_variable(self) -> str:
		"""SCPI: SEQuence:ITEM:IPM:SOURce:VARiable \n
		Snippet: value: str = driver.sequence.item.ipm.source.get_variable() \n
		Sets the variable that defines the variation. \n
			:return: variable: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:SOURce:VARiable?')
		return trim_str_response(response)

	def set_variable(self, variable: str) -> None:
		"""SCPI: SEQuence:ITEM:IPM:SOURce:VARiable \n
		Snippet: driver.sequence.item.ipm.source.set_variable(variable = '1') \n
		Sets the variable that defines the variation. \n
			:param variable: string
		"""
		param = Conversions.value_to_quoted_str(variable)
		self._core.io.write(f'SEQuence:ITEM:IPM:SOURce:VARiable {param}')

	def get_value(self) -> str:
		"""SCPI: SEQuence:ITEM:IPM:SOURce \n
		Snippet: value: str = driver.sequence.item.ipm.source.get_value() \n
		Selects the profile source. Use the command method RsPulseSeq.Ipm.catalog to querry the existing profiles. \n
			:return: source: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:IPM:SOURce?')
		return trim_str_response(response)

	def set_value(self, source: str) -> None:
		"""SCPI: SEQuence:ITEM:IPM:SOURce \n
		Snippet: driver.sequence.item.ipm.source.set_value(source = '1') \n
		Selects the profile source. Use the command method RsPulseSeq.Ipm.catalog to querry the existing profiles. \n
			:param source: string
		"""
		param = Conversions.value_to_quoted_str(source)
		self._core.io.write(f'SEQuence:ITEM:IPM:SOURce {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Scenario:
	"""Scenario commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scenario", core, parent)

	def get_duration(self) -> float:
		"""SCPI: SCENario:OUTPut:MARKer:SCENario:DURation \n
		Snippet: value: float = driver.scenario.output.marker.scenario.get_duration() \n
		Sets the duration of the scenario marker. \n
			:return: duration: float Range: 0 to 1, Unit: sec
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MARKer:SCENario:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: SCENario:OUTPut:MARKer:SCENario:DURation \n
		Snippet: driver.scenario.output.marker.scenario.set_duration(duration = 1.0) \n
		Sets the duration of the scenario marker. \n
			:param duration: float Range: 0 to 1, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SCENario:OUTPut:MARKer:SCENario:DURation {param}')

	def get_enable(self) -> bool:
		"""SCPI: SCENario:OUTPut:MARKer:SCENario:ENABle \n
		Snippet: value: bool = driver.scenario.output.marker.scenario.get_enable() \n
		Enables an additional marker, that is held high from the scenario start until the duration, selected with the command
		method RsPulseSeq.Scenario.Output.Marker.Scenario.duration. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:OUTPut:MARKer:SCENario:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:OUTPut:MARKer:SCENario:ENABle \n
		Snippet: driver.scenario.output.marker.scenario.set_enable(enable = False) \n
		Enables an additional marker, that is held high from the scenario start until the duration, selected with the command
		method RsPulseSeq.Scenario.Output.Marker.Scenario.duration. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:OUTPut:MARKer:SCENario:ENABle {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.TimeMode:
		"""SCPI: SEQuence:TIME:MODE \n
		Snippet: value: enums.TimeMode = driver.sequence.time.get_mode() \n
		Switches between time-based (PRI) and frequency-based (PRF) pulse repetition definition. \n
			:return: mode: PRI| PRF
		"""
		response = self._core.io.query_str('SEQuence:TIME:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.TimeMode)

	def set_mode(self, mode: enums.TimeMode) -> None:
		"""SCPI: SEQuence:TIME:MODE \n
		Snippet: driver.sequence.time.set_mode(mode = enums.TimeMode.PRF) \n
		Switches between time-based (PRI) and frequency-based (PRF) pulse repetition definition. \n
			:param mode: PRI| PRF
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.TimeMode)
		self._core.io.write(f'SEQuence:TIME:MODE {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Waveform:
	"""Waveform commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("waveform", core, parent)

	def clear(self) -> None:
		"""SCPI: WAVeform:WAVeform:CLEar \n
		Snippet: driver.waveform.waveform.clear() \n
		Removes the imported waveform or file with I/Q data. \n
		"""
		self._core.io.write(f'WAVeform:WAVeform:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: WAVeform:WAVeform:CLEar \n
		Snippet: driver.waveform.waveform.clear_with_opc() \n
		Removes the imported waveform or file with I/Q data. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'WAVeform:WAVeform:CLEar', opc_timeout_ms)

	def load(self, load: str) -> None:
		"""SCPI: WAVeform:WAVeform:LOAD \n
		Snippet: driver.waveform.waveform.load(load = '1') \n
		Load the selected waveform file (*.wv) , see Table 'Supported file types'. \n
			:param load: string Complete file path with file name and extension
		"""
		param = Conversions.value_to_quoted_str(load)
		self._core.io.write(f'WAVeform:WAVeform:LOAD {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pdw:
	"""Pdw commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pdw", core, parent)

	def load(self) -> None:
		"""SCPI: IMPort:PDW:FILE:PDW:LOAD \n
		Snippet: driver.importPy.pdw.file.pdw.load() \n
		Loads the selected file. \n
		"""
		self._core.io.write(f'IMPort:PDW:FILE:PDW:LOAD')

	def load_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: IMPort:PDW:FILE:PDW:LOAD \n
		Snippet: driver.importPy.pdw.file.pdw.load_with_opc() \n
		Loads the selected file. \n
		Same as load, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'IMPort:PDW:FILE:PDW:LOAD', opc_timeout_ms)

	def save(self) -> None:
		"""SCPI: IMPort:PDW:FILE:PDW:SAVE \n
		Snippet: driver.importPy.pdw.file.pdw.save() \n
		Stores the selected file. \n
		"""
		self._core.io.write(f'IMPort:PDW:FILE:PDW:SAVE')

	def save_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: IMPort:PDW:FILE:PDW:SAVE \n
		Snippet: driver.importPy.pdw.file.pdw.save_with_opc() \n
		Stores the selected file. \n
		Same as save, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'IMPort:PDW:FILE:PDW:SAVE', opc_timeout_ms)

	def get_value(self) -> str:
		"""SCPI: IMPort:PDW:FILE:PDW \n
		Snippet: value: str = driver.importPy.pdw.file.pdw.get_value() \n
		Sets or queries the name of the used PDW list file. \n
			:return: pdw: absolute file path and filename, incl. file extension
		"""
		response = self._core.io.query_str('IMPort:PDW:FILE:PDW?')
		return trim_str_response(response)

	def set_value(self, pdw: str) -> None:
		"""SCPI: IMPort:PDW:FILE:PDW \n
		Snippet: driver.importPy.pdw.file.pdw.set_value(pdw = '1') \n
		Sets or queries the name of the used PDW list file. \n
			:param pdw: absolute file path and filename, incl. file extension
		"""
		param = Conversions.value_to_quoted_str(pdw)
		self._core.io.write(f'IMPort:PDW:FILE:PDW {param}')



from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup
from ..Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Script:
	"""Script commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("script", core, parent)

	def set_add(self, add: str) -> None:
		"""SCPI: SCRipt:ADD \n
		Snippet: driver.script.set_add(add = '1') \n
		No command help available \n
			:param add: No help available
		"""
		param = Conversions.value_to_quoted_str(add)
		self._core.io.write(f'SCRipt:ADD {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Plugin:
	"""Plugin commands group definition. 6 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("plugin", core, parent)

	@property
	def variable(self):
		"""variable commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_variable'):
			from .Variable import Variable
			self._variable = Variable(self._core, self._cmd_group)
		return self._variable

	def get_name(self) -> str:
		"""SCPI: IPM:PLUGin:NAME \n
		Snippet: value: str = driver.ipm.plugin.get_name() \n
		Renames the selected repository element. \n
			:return: name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		response = self._core.io.query_str('IPM:PLUGin:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: IPM:PLUGin:NAME \n
		Snippet: driver.ipm.plugin.set_name(name = '1') \n
		Renames the selected repository element. \n
			:param name: string Must be unique for the particular type of repository elements. May contain empty spaces.
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'IPM:PLUGin:NAME {param}')

	def clone(self) -> 'Plugin':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Plugin(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Volatile:
	"""Volatile commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("volatile", core, parent)

	def get_path(self) -> str:
		"""SCPI: REPository:VOLatile:PATH \n
		Snippet: value: str = driver.repository.volatile.get_path() \n
		Queries the directory in that the volatile data is saved. \n
			:return: path: string
		"""
		response = self._core.io.query_str('REPository:VOLatile:PATH?')
		return trim_str_response(response)



from typing import List

from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Instrument:
	"""Instrument commands group definition. 19 total commands, 1 Subgroups, 18 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("instrument", core, parent)

	@property
	def adb(self):
		"""adb commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_adb'):
			from .Adb import Adb
			self._adb = Adb(self._core, self._cmd_group)
		return self._adb

	def set_add(self, add: str) -> None:
		"""SCPI: INSTrument:ADD \n
		Snippet: driver.instrument.set_add(add = '1') \n
		Adds an instrument with the specified IP address, computer name, or the VISA resource string. \n
			:param add: string 'IP_Address' or 'Computer_Name' or 'GPIB_Address'
		"""
		param = Conversions.value_to_quoted_str(add)
		self._core.io.write(f'INSTrument:ADD {param}')

	def get_capabilities(self) -> str:
		"""SCPI: INSTrument:CAPabilities \n
		Snippet: value: str = driver.instrument.get_capabilities() \n
		Queries the generator capabilities regarding supported scenario types and processing of waveforms and multi-segment files. \n
			:return: capabilities: string
		"""
		response = self._core.io.query_str('INSTrument:CAPabilities?')
		return trim_str_response(response)

	def set_capabilities(self, capabilities: str) -> None:
		"""SCPI: INSTrument:CAPabilities \n
		Snippet: driver.instrument.set_capabilities(capabilities = '1') \n
		Queries the generator capabilities regarding supported scenario types and processing of waveforms and multi-segment files. \n
			:param capabilities: string
		"""
		param = Conversions.value_to_quoted_str(capabilities)
		self._core.io.write(f'INSTrument:CAPabilities {param}')

	def clear(self) -> None:
		"""SCPI: INSTrument:CLEar \n
		Snippet: driver.instrument.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'INSTrument:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: INSTrument:CLEar \n
		Snippet: driver.instrument.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'INSTrument:CLEar', opc_timeout_ms)

	def get_comment(self) -> str:
		"""SCPI: INSTrument:COMMent \n
		Snippet: value: str = driver.instrument.get_comment() \n
		Adds a description to the selected repository element. \n
			:return: comment: string
		"""
		response = self._core.io.query_str('INSTrument:COMMent?')
		return trim_str_response(response)

	def set_comment(self, comment: str) -> None:
		"""SCPI: INSTrument:COMMent \n
		Snippet: driver.instrument.set_comment(comment = '1') \n
		Adds a description to the selected repository element. \n
			:param comment: string
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'INSTrument:COMMent {param}')

	def set_connect(self, connect: str) -> None:
		"""SCPI: INSTrument:CONNect \n
		Snippet: driver.instrument.set_connect(connect = '1') \n
		Connects to the instrument defined by method RsPulseSeq.Instrument.select \n
			:param connect: string
		"""
		param = Conversions.value_to_quoted_str(connect)
		self._core.io.write(f'INSTrument:CONNect {param}')

	def get_count(self) -> float:
		"""SCPI: INSTrument:COUNt \n
		Snippet: value: float = driver.instrument.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('INSTrument:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: INSTrument:DELete \n
		Snippet: driver.instrument.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'INSTrument:DELete {param}')

	def get_firmware(self) -> str:
		"""SCPI: INSTrument:FIRMware \n
		Snippet: value: str = driver.instrument.get_firmware() \n
		Queries the firmware version of the selected instrument. \n
			:return: firmware: string
		"""
		response = self._core.io.query_str('INSTrument:FIRMware?')
		return trim_str_response(response)

	def get_list_py(self) -> List[int]:
		"""SCPI: INSTrument:LIST \n
		Snippet: value: List[int] = driver.instrument.get_list_py() \n
		Queries the names of the signal generators that are connected to the R&S Pulse Sequencer in the current setup. See method
		RsPulseSeq.Setup.listPy. \n
			:return: list_py: 'Instr#1','Instr#2',...
		"""
		response = self._core.io.query_bin_or_ascii_int_list('INSTrument:LIST?')
		return response

	def get_name(self) -> str:
		"""SCPI: INSTrument:NAME \n
		Snippet: value: str = driver.instrument.get_name() \n
		Queries the name of the selected instrument. \n
			:return: name: string
		"""
		response = self._core.io.query_str('INSTrument:NAME?')
		return trim_str_response(response)

	def set_name(self, name: str) -> None:
		"""SCPI: INSTrument:NAME \n
		Snippet: driver.instrument.set_name(name = '1') \n
		Queries the name of the selected instrument. \n
			:param name: string
		"""
		param = Conversions.value_to_quoted_str(name)
		self._core.io.write(f'INSTrument:NAME {param}')

	def get_online(self) -> float:
		"""SCPI: INSTrument:ONLine \n
		Snippet: value: float = driver.instrument.get_online() \n
		Queries the connection status of a physical signal generator. \n
			:return: online: float 0 Offline 1 Online
		"""
		response = self._core.io.query_str('INSTrument:ONLine?')
		return Conversions.str_to_float(response)

	def set_online(self, online: float) -> None:
		"""SCPI: INSTrument:ONLine \n
		Snippet: driver.instrument.set_online(online = 1.0) \n
		Queries the connection status of a physical signal generator. \n
			:param online: float 0 Offline 1 Online
		"""
		param = Conversions.decimal_value_to_str(online)
		self._core.io.write(f'INSTrument:ONLine {param}')

	# noinspection PyTypeChecker
	def get_pmod(self) -> enums.PmodSource:
		"""SCPI: INSTrument:PMOD \n
		Snippet: value: enums.PmodSource = driver.instrument.get_pmod() \n
		Select the marker source if pulse modulator is used, see method RsPulseSeq.Setup.Pmod.enable. \n
			:return: pmod: OFF| INTernal| EXTernal OFF Disables the function for the selected instrument. INTernal No additional cabling or configuration of marker signals is required. EXTernal Requires that: 1) the instruments are cabled according to the wiring diagram 2) high the clock rate is selected 3) pulse marker M2 is set to pulse width 4) sequence marker M2 is enabled 5) the generation of the dedicated marker signal is enabled
		"""
		response = self._core.io.query_str('INSTrument:PMOD?')
		return Conversions.str_to_scalar_enum(response, enums.PmodSource)

	def set_pmod(self, pmod: enums.PmodSource) -> None:
		"""SCPI: INSTrument:PMOD \n
		Snippet: driver.instrument.set_pmod(pmod = enums.PmodSource.EXTernal) \n
		Select the marker source if pulse modulator is used, see method RsPulseSeq.Setup.Pmod.enable. \n
			:param pmod: OFF| INTernal| EXTernal OFF Disables the function for the selected instrument. INTernal No additional cabling or configuration of marker signals is required. EXTernal Requires that: 1) the instruments are cabled according to the wiring diagram 2) high the clock rate is selected 3) pulse marker M2 is set to pulse width 4) sequence marker M2 is enabled 5) the generation of the dedicated marker signal is enabled
		"""
		param = Conversions.enum_scalar_to_str(pmod, enums.PmodSource)
		self._core.io.write(f'INSTrument:PMOD {param}')

	# noinspection PyTypeChecker
	def get_psec(self) -> enums.Psec:
		"""SCPI: INSTrument:PSEC \n
		Snippet: value: enums.Psec = driver.instrument.get_psec() \n
		Sets the Primary/Secondary order in synchronized setups. \n
			:return: psec: NONE| PRIMary| SEC1| SEC2| SEC3| SEC4| SEC5| SEC6| SEC7| SEC8| SEC9| SEC10| SEC11| SEC12| SEC13| SEC14| SEC15| SEC16 NONE Unsynchronized instrument. PRIMary The primary instrument. SEC1 Denotes the secondary instruments.
		"""
		response = self._core.io.query_str('INSTrument:PSEC?')
		return Conversions.str_to_scalar_enum(response, enums.Psec)

	def set_psec(self, psec: enums.Psec) -> None:
		"""SCPI: INSTrument:PSEC \n
		Snippet: driver.instrument.set_psec(psec = enums.Psec.NONE) \n
		Sets the Primary/Secondary order in synchronized setups. \n
			:param psec: NONE| PRIMary| SEC1| SEC2| SEC3| SEC4| SEC5| SEC6| SEC7| SEC8| SEC9| SEC10| SEC11| SEC12| SEC13| SEC14| SEC15| SEC16 NONE Unsynchronized instrument. PRIMary The primary instrument. SEC1 Denotes the secondary instruments.
		"""
		param = Conversions.enum_scalar_to_str(psec, enums.Psec)
		self._core.io.write(f'INSTrument:PSEC {param}')

	def get_resource(self) -> str:
		"""SCPI: INSTrument:RESource \n
		Snippet: value: str = driver.instrument.get_resource() \n
		Queries the resource string of the instrument selected with the command method RsPulseSeq.Instrument.select. \n
			:return: resource: string
		"""
		response = self._core.io.query_str('INSTrument:RESource?')
		return trim_str_response(response)

	def get_select(self) -> float:
		"""SCPI: INSTrument:SELect \n
		Snippet: value: float = driver.instrument.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('INSTrument:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: INSTrument:SELect \n
		Snippet: driver.instrument.set_select(select = 1.0) \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'INSTrument:SELect {param}')

	def get_supported(self) -> float:
		"""SCPI: INSTrument:SUPPorted \n
		Snippet: value: float = driver.instrument.get_supported() \n
		Queries the supported status. \n
			:return: supported: 0| 1 1 Supported 0 Not supported
		"""
		response = self._core.io.query_str('INSTrument:SUPPorted?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.GeneratorType:
		"""SCPI: INSTrument:TYPE \n
		Snippet: value: enums.GeneratorType = driver.instrument.get_type_py() \n
		No command help available \n
			:return: type_py: SMU| SMM| SMBB| SW| SGT| SMBV| SMJ| SMW
		"""
		response = self._core.io.query_str('INSTrument:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.GeneratorType)

	def set_type_py(self, type_py: enums.GeneratorType) -> None:
		"""SCPI: INSTrument:TYPE \n
		Snippet: driver.instrument.set_type_py(type_py = enums.GeneratorType.SGT) \n
		No command help available \n
			:param type_py: SMU| SMM| SMBB| SW| SGT| SMBV| SMJ| SMW
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.GeneratorType)
		self._core.io.write(f'INSTrument:TYPE {param}')

	def get_virtual(self) -> bool:
		"""SCPI: INSTrument:VIRTual \n
		Snippet: value: bool = driver.instrument.get_virtual() \n
		No command help available \n
			:return: virtual: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('INSTrument:VIRTual?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'Instrument':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Instrument(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Custom:
	"""Custom commands group definition. 13 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("custom", core, parent)

	@property
	def entry(self):
		"""entry commands group. 1 Sub-classes, 10 commands."""
		if not hasattr(self, '_entry'):
			from .Entry import Entry
			self._entry = Entry(self._core, self._cmd_group)
		return self._entry

	@property
	def importPy(self):
		"""importPy commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_importPy'):
			from .ImportPy import ImportPy
			self._importPy = ImportPy(self._core, self._cmd_group)
		return self._importPy

	def clone(self) -> 'Custom':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Custom(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Maps:
	"""Maps commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("maps", core, parent)

	def get_enable(self) -> bool:
		"""SCPI: SCENario:LOCalized:MAPS:ENABle \n
		Snippet: value: bool = driver.scenario.localized.maps.get_enable() \n
		Enable maps for the selected scenario. This operation cannot be undone. \n
			:return: enable: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:LOCalized:MAPS:ENABle?')
		return Conversions.str_to_bool(response)

	def set_enable(self, enable: bool) -> None:
		"""SCPI: SCENario:LOCalized:MAPS:ENABle \n
		Snippet: driver.scenario.localized.maps.set_enable(enable = False) \n
		Enable maps for the selected scenario. This operation cannot be undone. \n
			:param enable: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(enable)
		self._core.io.write(f'SCENario:LOCalized:MAPS:ENABle {param}')

	def load(self, load: List[int]) -> None:
		"""SCPI: SCENario:LOCalized:MAPS:LOAD \n
		Snippet: driver.scenario.localized.maps.load(load = [1, 2, 3]) \n
		This command loads a georeferenced map for the selected scenario. Supported formats:
			INTRO_CMD_HELP: Examples of special characters: \n
			- .tif
			- .tiff \n
			:param load: No help available
		"""
		param = Conversions.list_to_csv_str(load)
		self._core.io.write(f'SCENario:LOCalized:MAPS:LOAD {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Zoom:
	"""Zoom commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("zoom", core, parent)

	def set_point(self, point: float) -> None:
		"""SCPI: SCENario:VOLatile:VIEW:ZOOM:POINt \n
		Snippet: driver.scenario.volatile.view.zoom.set_point(point = 1.0) \n
		Sets center point of the displayed area. \n
			:param point: float Always related to time Unit: s
		"""
		param = Conversions.decimal_value_to_str(point)
		self._core.io.write(f'SCENario:VOLatile:VIEW:ZOOM:POINt {param}')

	def set_range(self, range_py: float) -> None:
		"""SCPI: SCENario:VOLatile:VIEW:ZOOM:RANGe \n
		Snippet: driver.scenario.volatile.view.zoom.set_range(range_py = 1.0) \n
		Sets the displayed waveform part as a range around the selected center point, set with the command method RsPulseSeq.
		Scenario.Volatile.View.Zoom.point. \n
			:param range_py: float Expressed as a time span (units can be omitted) or as number of samples
		"""
		param = Conversions.decimal_value_to_str(range_py)
		self._core.io.write(f'SCENario:VOLatile:VIEW:ZOOM:RANGe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 3 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	@property
	def dsrc(self):
		"""dsrc commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_dsrc'):
			from .Dsrc import Dsrc
			self._dsrc = Dsrc(self._core, self._cmd_group)
		return self._dsrc

	# noinspection PyTypeChecker
	def get_coding(self) -> enums.Coding:
		"""SCPI: PULSe:MOP:DATA:CODing \n
		Snippet: value: enums.Coding = driver.pulse.mop.data.get_coding() \n
		Selects the data coding scheme. \n
			:return: coding: NONE| DIFFerential| GRAY| DGRay
		"""
		response = self._core.io.query_str('PULSe:MOP:DATA:CODing?')
		return Conversions.str_to_scalar_enum(response, enums.Coding)

	def set_coding(self, coding: enums.Coding) -> None:
		"""SCPI: PULSe:MOP:DATA:CODing \n
		Snippet: driver.pulse.mop.data.set_coding(coding = enums.Coding.DGRay) \n
		Selects the data coding scheme. \n
			:param coding: NONE| DIFFerential| GRAY| DGRay
		"""
		param = Conversions.enum_scalar_to_str(coding, enums.Coding)
		self._core.io.write(f'PULSe:MOP:DATA:CODing {param}')

	def clone(self) -> 'Data':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Data(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Conical:
	"""Conical commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("conical", core, parent)

	def get_rate(self) -> float:
		"""SCPI: SCAN:CONical:RATE \n
		Snippet: value: float = driver.scan.conical.get_rate() \n
		Sets the turning speed. \n
			:return: rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		response = self._core.io.query_str('SCAN:CONical:RATE?')
		return Conversions.str_to_float(response)

	def set_rate(self, rate: float) -> None:
		"""SCPI: SCAN:CONical:RATE \n
		Snippet: driver.scan.conical.set_rate(rate = 1.0) \n
		Sets the turning speed. \n
			:param rate: float Range: 0.01 to 100000, Unit: degree/s
		"""
		param = Conversions.decimal_value_to_str(rate)
		self._core.io.write(f'SCAN:CONical:RATE {param}')

	# noinspection PyTypeChecker
	def get_rotation(self) -> enums.Rotation:
		"""SCPI: SCAN:CONical:ROTation \n
		Snippet: value: enums.Rotation = driver.scan.conical.get_rotation() \n
		Sets the rotation direction of the antenna. \n
			:return: rotation: CW| CCW
		"""
		response = self._core.io.query_str('SCAN:CONical:ROTation?')
		return Conversions.str_to_scalar_enum(response, enums.Rotation)

	def set_rotation(self, rotation: enums.Rotation) -> None:
		"""SCPI: SCAN:CONical:ROTation \n
		Snippet: driver.scan.conical.set_rotation(rotation = enums.Rotation.CCW) \n
		Sets the rotation direction of the antenna. \n
			:param rotation: CW| CCW
		"""
		param = Conversions.enum_scalar_to_str(rotation, enums.Rotation)
		self._core.io.write(f'SCAN:CONical:ROTation {param}')

	def get_squint(self) -> float:
		"""SCPI: SCAN:CONical:SQUint \n
		Snippet: value: float = driver.scan.conical.get_squint() \n
		Sets the offset angle of the antenna beam, that means for the conical antenna the parameter sets the radius of the
		scanned circle. \n
			:return: squint: float Range: 0.05 to 15, Unit: degree
		"""
		response = self._core.io.query_str('SCAN:CONical:SQUint?')
		return Conversions.str_to_float(response)

	def set_squint(self, squint: float) -> None:
		"""SCPI: SCAN:CONical:SQUint \n
		Snippet: driver.scan.conical.set_squint(squint = 1.0) \n
		Sets the offset angle of the antenna beam, that means for the conical antenna the parameter sets the radius of the
		scanned circle. \n
			:param squint: float Range: 0.05 to 15, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(squint)
		self._core.io.write(f'SCAN:CONical:SQUint {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SoQpsk:
	"""SoQpsk commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("soQpsk", core, parent)

	def get_irig(self) -> bool:
		"""SCPI: PULSe:MOP:QPSK:SOQPsk:IRIG \n
		Snippet: value: bool = driver.pulse.mop.qpsk.soQpsk.get_irig() \n
		Enables differential encoding according to the telemetry standard IRIG 106-04. \n
			:return: irig: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('PULSe:MOP:QPSK:SOQPsk:IRIG?')
		return Conversions.str_to_bool(response)

	def set_irig(self, irig: bool) -> None:
		"""SCPI: PULSe:MOP:QPSK:SOQPsk:IRIG \n
		Snippet: driver.pulse.mop.qpsk.soQpsk.set_irig(irig = False) \n
		Enables differential encoding according to the telemetry standard IRIG 106-04. \n
			:param irig: ON| OFF| 1| 0
		"""
		param = Conversions.bool_to_str(irig)
		self._core.io.write(f'PULSe:MOP:QPSK:SOQPsk:IRIG {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Volatile:
	"""Volatile commands group definition. 4 total commands, 2 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("volatile", core, parent)

	@property
	def release(self):
		"""release commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_release'):
			from .Release import Release
			self._release = Release(self._core, self._cmd_group)
		return self._release

	@property
	def restore(self):
		"""restore commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_restore'):
			from .Restore import Restore
			self._restore = Restore(self._core, self._cmd_group)
		return self._restore

	def clear(self) -> None:
		"""SCPI: SCENario:CACHe:VOLatile:CLEar \n
		Snippet: driver.scenario.cache.volatile.clear() \n
		Deletes the files from the volatile/repository memory. \n
		"""
		self._core.io.write(f'SCENario:CACHe:VOLatile:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:CACHe:VOLatile:CLEar \n
		Snippet: driver.scenario.cache.volatile.clear_with_opc() \n
		Deletes the files from the volatile/repository memory. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:CACHe:VOLatile:CLEar', opc_timeout_ms)

	def get_valid(self) -> bool:
		"""SCPI: SCENario:CACHe:VOLatile:VALid \n
		Snippet: value: bool = driver.scenario.cache.volatile.get_valid() \n
		Queries whether the volatile/repository memory contains a valid signal file. \n
			:return: valid: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:CACHe:VOLatile:VALid?')
		return Conversions.str_to_bool(response)

	def clone(self) -> 'Volatile':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Volatile(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RamBuff:
	"""RamBuff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ramBuff", core, parent)

	# noinspection PyTypeChecker
	def get_size(self) -> enums.BufferSize:
		"""SCPI: PROGram:RAMBuff:SIZE \n
		Snippet: value: enums.BufferSize = driver.program.ramBuff.get_size() \n
		Sets the ARB RAM buffer size. \n
			:return: size: 16M| 64M| 128M| 256M| 512M| 1G
		"""
		response = self._core.io.query_str('PROGram:RAMBuff:SIZE?')
		return Conversions.str_to_scalar_enum(response, enums.BufferSize)

	def set_size(self, size: enums.BufferSize) -> None:
		"""SCPI: PROGram:RAMBuff:SIZE \n
		Snippet: driver.program.ramBuff.set_size(size = enums.BufferSize._128M) \n
		Sets the ARB RAM buffer size. \n
			:param size: 16M| 64M| 128M| 256M| 512M| 1G
		"""
		param = Conversions.enum_scalar_to_str(size, enums.BufferSize)
		self._core.io.write(f'PROGram:RAMBuff:SIZE {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Binomial:
	"""Binomial commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("binomial", core, parent)

	def get_pval_1(self) -> float:
		"""SCPI: IPM:BINomial:PVAL1 \n
		Snippet: value: float = driver.ipm.binomial.get_pval_1() \n
		Sets the probability of occurrence of value 1 in the binomial distribution function. \n
			:return: pval_1: float Range: 0 to 100, Unit: PCT
		"""
		response = self._core.io.query_str('IPM:BINomial:PVAL1?')
		return Conversions.str_to_float(response)

	def set_pval_1(self, pval_1: float) -> None:
		"""SCPI: IPM:BINomial:PVAL1 \n
		Snippet: driver.ipm.binomial.set_pval_1(pval_1 = 1.0) \n
		Sets the probability of occurrence of value 1 in the binomial distribution function. \n
			:param pval_1: float Range: 0 to 100, Unit: PCT
		"""
		param = Conversions.decimal_value_to_str(pval_1)
		self._core.io.write(f'IPM:BINomial:PVAL1 {param}')

	def get_val_1(self) -> float:
		"""SCPI: IPM:BINomial:VAL1 \n
		Snippet: value: float = driver.ipm.binomial.get_val_1() \n
		Sets the values of the binomial distribution function. \n
			:return: val_1: No help available
		"""
		response = self._core.io.query_str('IPM:BINomial:VAL1?')
		return Conversions.str_to_float(response)

	def set_val_1(self, val_1: float) -> None:
		"""SCPI: IPM:BINomial:VAL1 \n
		Snippet: driver.ipm.binomial.set_val_1(val_1 = 1.0) \n
		Sets the values of the binomial distribution function. \n
			:param val_1: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(val_1)
		self._core.io.write(f'IPM:BINomial:VAL1 {param}')

	def get_val_2(self) -> float:
		"""SCPI: IPM:BINomial:VAL2 \n
		Snippet: value: float = driver.ipm.binomial.get_val_2() \n
		Sets the values of the binomial distribution function. \n
			:return: val_2: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:BINomial:VAL2?')
		return Conversions.str_to_float(response)

	def set_val_2(self, val_2: float) -> None:
		"""SCPI: IPM:BINomial:VAL2 \n
		Snippet: driver.ipm.binomial.set_val_2(val_2 = 1.0) \n
		Sets the values of the binomial distribution function. \n
			:param val_2: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(val_2)
		self._core.io.write(f'IPM:BINomial:VAL2 {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Time:
	"""Time commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	def get_equation(self) -> str:
		"""SCPI: SEQuence:ITEM:FILLer:TIME:EQUation \n
		Snippet: value: str = driver.sequence.item.filler.time.get_equation() \n
		Sets the filler duration as an equation. \n
			:return: equation: string
		"""
		response = self._core.io.query_str('SEQuence:ITEM:FILLer:TIME:EQUation?')
		return trim_str_response(response)

	def set_equation(self, equation: str) -> None:
		"""SCPI: SEQuence:ITEM:FILLer:TIME:EQUation \n
		Snippet: driver.sequence.item.filler.time.set_equation(equation = '1') \n
		Sets the filler duration as an equation. \n
			:param equation: string
		"""
		param = Conversions.value_to_quoted_str(equation)
		self._core.io.write(f'SEQuence:ITEM:FILLer:TIME:EQUation {param}')

	def get_fixed(self) -> float:
		"""SCPI: SEQuence:ITEM:FILLer:TIME:FIXed \n
		Snippet: value: float = driver.sequence.item.filler.time.get_fixed() \n
		Sets the duration of the filler. \n
			:return: fixed: float Range: 0 to 1e+09, Unit: sec
		"""
		response = self._core.io.query_str('SEQuence:ITEM:FILLer:TIME:FIXed?')
		return Conversions.str_to_float(response)

	def set_fixed(self, fixed: float) -> None:
		"""SCPI: SEQuence:ITEM:FILLer:TIME:FIXed \n
		Snippet: driver.sequence.item.filler.time.set_fixed(fixed = 1.0) \n
		Sets the duration of the filler. \n
			:param fixed: float Range: 0 to 1e+09, Unit: sec
		"""
		param = Conversions.decimal_value_to_str(fixed)
		self._core.io.write(f'SEQuence:ITEM:FILLer:TIME:FIXed {param}')

	# noinspection PyTypeChecker
	def get_value(self) -> enums.FillerTime:
		"""SCPI: SEQuence:ITEM:FILLer:TIME \n
		Snippet: value: enums.FillerTime = driver.sequence.item.filler.time.get_value() \n
		Defines the way the duration is defined. \n
			:return: time: FIXed| EQUation
		"""
		response = self._core.io.query_str('SEQuence:ITEM:FILLer:TIME?')
		return Conversions.str_to_scalar_enum(response, enums.FillerTime)

	def set_value(self, time: enums.FillerTime) -> None:
		"""SCPI: SEQuence:ITEM:FILLer:TIME \n
		Snippet: driver.sequence.item.filler.time.set_value(time = enums.FillerTime.EQUation) \n
		Defines the way the duration is defined. \n
			:param time: FIXed| EQUation
		"""
		param = Conversions.enum_scalar_to_str(time, enums.FillerTime)
		self._core.io.write(f'SEQuence:ITEM:FILLer:TIME {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Csequence:
	"""Csequence commands group definition. 8 total commands, 1 Subgroups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("csequence", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def get_alias(self) -> str:
		"""SCPI: SCENario:CSEQuence:ALIas \n
		Snippet: value: str = driver.scenario.csequence.get_alias() \n
		Enters an alias name. \n
			:return: alias: string
		"""
		response = self._core.io.query_str('SCENario:CSEQuence:ALIas?')
		return trim_str_response(response)

	def set_alias(self, alias: str) -> None:
		"""SCPI: SCENario:CSEQuence:ALIas \n
		Snippet: driver.scenario.csequence.set_alias(alias = '1') \n
		Enters an alias name. \n
			:param alias: string
		"""
		param = Conversions.value_to_quoted_str(alias)
		self._core.io.write(f'SCENario:CSEQuence:ALIas {param}')

	def clear(self) -> None:
		"""SCPI: SCENario:CSEQuence:CLEar \n
		Snippet: driver.scenario.csequence.clear() \n
		Deletes all items from the list or the table. \n
		"""
		self._core.io.write(f'SCENario:CSEQuence:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:CSEQuence:CLEar \n
		Snippet: driver.scenario.csequence.clear_with_opc() \n
		Deletes all items from the list or the table. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:CSEQuence:CLEar', opc_timeout_ms)

	def get_current(self) -> float:
		"""SCPI: SCENario:CSEQuence:CURRent \n
		Snippet: value: float = driver.scenario.csequence.get_current() \n
		Sets the sequence/emitter that is used by the scenario. \n
			:return: current: float Number of the sequence/emitter in the list with multiple sequences
		"""
		response = self._core.io.query_str('SCENario:CSEQuence:CURRent?')
		return Conversions.str_to_float(response)

	def set_current(self, current: float) -> None:
		"""SCPI: SCENario:CSEQuence:CURRent \n
		Snippet: driver.scenario.csequence.set_current(current = 1.0) \n
		Sets the sequence/emitter that is used by the scenario. \n
			:param current: float Number of the sequence/emitter in the list with multiple sequences
		"""
		param = Conversions.decimal_value_to_str(current)
		self._core.io.write(f'SCENario:CSEQuence:CURRent {param}')

	def delete(self, delete: float) -> None:
		"""SCPI: SCENario:CSEQuence:DELete \n
		Snippet: driver.scenario.csequence.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SCENario:CSEQuence:DELete {param}')

	def get_select(self) -> float:
		"""SCPI: SCENario:CSEQuence:SELect \n
		Snippet: value: float = driver.scenario.csequence.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SCENario:CSEQuence:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCENario:CSEQuence:SELect \n
		Snippet: driver.scenario.csequence.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCENario:CSEQuence:SELect {param}')

	def get_variable(self) -> str:
		"""SCPI: SCENario:CSEQuence:VARiable \n
		Snippet: value: str = driver.scenario.csequence.get_variable() \n
		Sets the collection variable. \n
			:return: variable: string
		"""
		response = self._core.io.query_str('SCENario:CSEQuence:VARiable?')
		return trim_str_response(response)

	def set_variable(self, variable: str) -> None:
		"""SCPI: SCENario:CSEQuence:VARiable \n
		Snippet: driver.scenario.csequence.set_variable(variable = '1') \n
		Sets the collection variable. \n
			:param variable: string
		"""
		param = Conversions.value_to_quoted_str(variable)
		self._core.io.write(f'SCENario:CSEQuence:VARiable {param}')

	def get_value(self) -> str:
		"""SCPI: SCENario:CSEQuence \n
		Snippet: value: str = driver.scenario.csequence.get_value() \n
		Select an existing sequence, see method RsPulseSeq.Sequence.catalog. \n
			:return: csequence: string
		"""
		response = self._core.io.query_str('SCENario:CSEQuence?')
		return trim_str_response(response)

	def set_value(self, csequence: str) -> None:
		"""SCPI: SCENario:CSEQuence \n
		Snippet: driver.scenario.csequence.set_value(csequence = '1') \n
		Select an existing sequence, see method RsPulseSeq.Sequence.catalog. \n
			:param csequence: string
		"""
		param = Conversions.value_to_quoted_str(csequence)
		self._core.io.write(f'SCENario:CSEQuence {param}')

	def clone(self) -> 'Csequence':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Csequence(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Auto:
	"""Auto commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def get_border(self) -> float:
		"""SCPI: SCENario:OUTPut:CLOCk:AUTO:BORDer \n
		Snippet: value: float = driver.scenario.output.clock.auto.get_border() \n
		Sets the minimum clock rate. \n
			:return: border: float Range: 1000 to 1e+08
		"""
		response = self._core.io.query_str('SCENario:OUTPut:CLOCk:AUTO:BORDer?')
		return Conversions.str_to_float(response)

	def set_border(self, border: float) -> None:
		"""SCPI: SCENario:OUTPut:CLOCk:AUTO:BORDer \n
		Snippet: driver.scenario.output.clock.auto.set_border(border = 1.0) \n
		Sets the minimum clock rate. \n
			:param border: float Range: 1000 to 1e+08
		"""
		param = Conversions.decimal_value_to_str(border)
		self._core.io.write(f'SCENario:OUTPut:CLOCk:AUTO:BORDer {param}')

	def get_oversampling(self) -> float:
		"""SCPI: SCENario:OUTPut:CLOCk:AUTO:OVERsampling \n
		Snippet: value: float = driver.scenario.output.clock.auto.get_oversampling() \n
		Sets the minimum oversampling factor. \n
			:return: oversampling: float Range: 1 to 1000
		"""
		response = self._core.io.query_str('SCENario:OUTPut:CLOCk:AUTO:OVERsampling?')
		return Conversions.str_to_float(response)

	def set_oversampling(self, oversampling: float) -> None:
		"""SCPI: SCENario:OUTPut:CLOCk:AUTO:OVERsampling \n
		Snippet: driver.scenario.output.clock.auto.set_oversampling(oversampling = 1.0) \n
		Sets the minimum oversampling factor. \n
			:param oversampling: float Range: 1 to 1000
		"""
		param = Conversions.decimal_value_to_str(oversampling)
		self._core.io.write(f'SCENario:OUTPut:CLOCk:AUTO:OVERsampling {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Bpsk:
	"""Bpsk commands group definition. 6 total commands, 1 Subgroups, 4 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bpsk", core, parent)

	@property
	def symbolRate(self):
		"""symbolRate commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_symbolRate'):
			from .SymbolRate import SymbolRate
			self._symbolRate = SymbolRate(self._core, self._cmd_group)
		return self._symbolRate

	def get_phase(self) -> float:
		"""SCPI: PULSe:MOP:BPSK:PHASe \n
		Snippet: value: float = driver.pulse.mop.bpsk.get_phase() \n
		Sets the phase. \n
			:return: phase: float Range: 0.1 to 180, Unit: degree
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:PHASe?')
		return Conversions.str_to_float(response)

	def set_phase(self, phase: float) -> None:
		"""SCPI: PULSe:MOP:BPSK:PHASe \n
		Snippet: driver.pulse.mop.bpsk.set_phase(phase = 1.0) \n
		Sets the phase. \n
			:param phase: float Range: 0.1 to 180, Unit: degree
		"""
		param = Conversions.decimal_value_to_str(phase)
		self._core.io.write(f'PULSe:MOP:BPSK:PHASe {param}')

	def get_ttime(self) -> float:
		"""SCPI: PULSe:MOP:BPSK:TTIMe \n
		Snippet: value: float = driver.pulse.mop.bpsk.get_ttime() \n
		Sets the transition time. \n
			:return: ttime: float Range: 0 to 50, Unit: percent
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:TTIMe?')
		return Conversions.str_to_float(response)

	def set_ttime(self, ttime: float) -> None:
		"""SCPI: PULSe:MOP:BPSK:TTIMe \n
		Snippet: driver.pulse.mop.bpsk.set_ttime(ttime = 1.0) \n
		Sets the transition time. \n
			:param ttime: float Range: 0 to 50, Unit: percent
		"""
		param = Conversions.decimal_value_to_str(ttime)
		self._core.io.write(f'PULSe:MOP:BPSK:TTIMe {param}')

	# noinspection PyTypeChecker
	def get_ttype(self) -> enums.BpskTtype:
		"""SCPI: PULSe:MOP:BPSK:TTYPe \n
		Snippet: value: enums.BpskTtype = driver.pulse.mop.bpsk.get_ttype() \n
		Selects the transition type. \n
			:return: ttype: LINear| COSine
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:TTYPe?')
		return Conversions.str_to_scalar_enum(response, enums.BpskTtype)

	def set_ttype(self, ttype: enums.BpskTtype) -> None:
		"""SCPI: PULSe:MOP:BPSK:TTYPe \n
		Snippet: driver.pulse.mop.bpsk.set_ttype(ttype = enums.BpskTtype.COSine) \n
		Selects the transition type. \n
			:param ttype: LINear| COSine
		"""
		param = Conversions.enum_scalar_to_str(ttype, enums.BpskTtype)
		self._core.io.write(f'PULSe:MOP:BPSK:TTYPe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.BpskType:
		"""SCPI: PULSe:MOP:BPSK:TYPE \n
		Snippet: value: enums.BpskType = driver.pulse.mop.bpsk.get_type_py() \n
		Sets the modulation type. \n
			:return: type_py: STANdard| CONStant
		"""
		response = self._core.io.query_str('PULSe:MOP:BPSK:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.BpskType)

	def set_type_py(self, type_py: enums.BpskType) -> None:
		"""SCPI: PULSe:MOP:BPSK:TYPE \n
		Snippet: driver.pulse.mop.bpsk.set_type_py(type_py = enums.BpskType.CONStant) \n
		Sets the modulation type. \n
			:param type_py: STANdard| CONStant
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.BpskType)
		self._core.io.write(f'PULSe:MOP:BPSK:TYPE {param}')

	def clone(self) -> 'Bpsk':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Bpsk(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Location:
	"""Location commands group definition. 15 total commands, 3 Subgroups, 9 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("location", core, parent)

	@property
	def pstep(self):
		"""pstep commands group. 1 Sub-classes, 3 commands."""
		if not hasattr(self, '_pstep'):
			from .Pstep import Pstep
			self._pstep = Pstep(self._core, self._cmd_group)
		return self._pstep

	@property
	def rec(self):
		"""rec commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rec'):
			from .Rec import Rec
			self._rec = Rec(self._core, self._cmd_group)
		return self._rec

	@property
	def waypoint(self):
		"""waypoint commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_waypoint'):
			from .Waypoint import Waypoint
			self._waypoint = Waypoint(self._core, self._cmd_group)
		return self._waypoint

	def get_altitude(self) -> float:
		"""SCPI: SCENario:DF:LOCation:ALTitude \n
		Snippet: value: float = driver.scenario.df.location.get_altitude() \n
		Use for defining the altitude of a fixed emitter (no movement) on a georeferenced map. \n
			:return: altitude: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:ALTitude?')
		return Conversions.str_to_float(response)

	def set_altitude(self, altitude: float) -> None:
		"""SCPI: SCENario:DF:LOCation:ALTitude \n
		Snippet: driver.scenario.df.location.set_altitude(altitude = 1.0) \n
		Use for defining the altitude of a fixed emitter (no movement) on a georeferenced map. \n
			:param altitude: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(altitude)
		self._core.io.write(f'SCENario:DF:LOCation:ALTitude {param}')

	def get_azimuth(self) -> float:
		"""SCPI: SCENario:DF:LOCation:AZIMuth \n
		Snippet: value: float = driver.scenario.df.location.get_azimuth() \n
		Sets the azimuth. \n
			:return: azimuth: float Range: 0 to 360
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:AZIMuth?')
		return Conversions.str_to_float(response)

	def set_azimuth(self, azimuth: float) -> None:
		"""SCPI: SCENario:DF:LOCation:AZIMuth \n
		Snippet: driver.scenario.df.location.set_azimuth(azimuth = 1.0) \n
		Sets the azimuth. \n
			:param azimuth: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(azimuth)
		self._core.io.write(f'SCENario:DF:LOCation:AZIMuth {param}')

	def get_east(self) -> float:
		"""SCPI: SCENario:DF:LOCation:EAST \n
		Snippet: value: float = driver.scenario.df.location.get_east() \n
		Sets the emitter coordinates. \n
			:return: east: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:EAST?')
		return Conversions.str_to_float(response)

	def set_east(self, east: float) -> None:
		"""SCPI: SCENario:DF:LOCation:EAST \n
		Snippet: driver.scenario.df.location.set_east(east = 1.0) \n
		Sets the emitter coordinates. \n
			:param east: float Range: -1e+09 to 1e+09, Unit: m
		"""
		param = Conversions.decimal_value_to_str(east)
		self._core.io.write(f'SCENario:DF:LOCation:EAST {param}')

	def get_elevation(self) -> float:
		"""SCPI: SCENario:DF:LOCation:ELEVation \n
		Snippet: value: float = driver.scenario.df.location.get_elevation() \n
		Sets the elevation. \n
			:return: elevation: float Range: -90 to 90
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:ELEVation?')
		return Conversions.str_to_float(response)

	def set_elevation(self, elevation: float) -> None:
		"""SCPI: SCENario:DF:LOCation:ELEVation \n
		Snippet: driver.scenario.df.location.set_elevation(elevation = 1.0) \n
		Sets the elevation. \n
			:param elevation: float Range: -90 to 90
		"""
		param = Conversions.decimal_value_to_str(elevation)
		self._core.io.write(f'SCENario:DF:LOCation:ELEVation {param}')

	def get_height(self) -> float:
		"""SCPI: SCENario:DF:LOCation:HEIGht \n
		Snippet: value: float = driver.scenario.df.location.get_height() \n
		Sets the height of the antenna. \n
			:return: height: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:HEIGht?')
		return Conversions.str_to_float(response)

	def set_height(self, height: float) -> None:
		"""SCPI: SCENario:DF:LOCation:HEIGht \n
		Snippet: driver.scenario.df.location.set_height(height = 1.0) \n
		Sets the height of the antenna. \n
			:param height: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(height)
		self._core.io.write(f'SCENario:DF:LOCation:HEIGht {param}')

	def get_latitude(self) -> float:
		"""SCPI: SCENario:DF:LOCation:LATitude \n
		Snippet: value: float = driver.scenario.df.location.get_latitude() \n
		Use for defining the position of a fixed emitter (no movement) on a georeferenced map. Positive values represent °East.
		Negative values represent °West. \n
			:return: latitude: No help available
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:LATitude?')
		return Conversions.str_to_float(response)

	def set_latitude(self, latitude: float) -> None:
		"""SCPI: SCENario:DF:LOCation:LATitude \n
		Snippet: driver.scenario.df.location.set_latitude(latitude = 1.0) \n
		Use for defining the position of a fixed emitter (no movement) on a georeferenced map. Positive values represent °East.
		Negative values represent °West. \n
			:param latitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(latitude)
		self._core.io.write(f'SCENario:DF:LOCation:LATitude {param}')

	def get_longitude(self) -> float:
		"""SCPI: SCENario:DF:LOCation:LONGitude \n
		Snippet: value: float = driver.scenario.df.location.get_longitude() \n
		Use for defining the position of a fixed emitter (no movement) on a georeferenced map. Positive values represent °East.
		Negative values represent °West. \n
			:return: longitude: float Range: -180 to 180
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:LONGitude?')
		return Conversions.str_to_float(response)

	def set_longitude(self, longitude: float) -> None:
		"""SCPI: SCENario:DF:LOCation:LONGitude \n
		Snippet: driver.scenario.df.location.set_longitude(longitude = 1.0) \n
		Use for defining the position of a fixed emitter (no movement) on a georeferenced map. Positive values represent °East.
		Negative values represent °West. \n
			:param longitude: float Range: -180 to 180
		"""
		param = Conversions.decimal_value_to_str(longitude)
		self._core.io.write(f'SCENario:DF:LOCation:LONGitude {param}')

	def get_north(self) -> float:
		"""SCPI: SCENario:DF:LOCation:NORTh \n
		Snippet: value: float = driver.scenario.df.location.get_north() \n
		Sets the emitter coordinates. \n
			:return: north: float Range: -1e+09 to 1e+09, Unit: m
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:NORTh?')
		return Conversions.str_to_float(response)

	def set_north(self, north: float) -> None:
		"""SCPI: SCENario:DF:LOCation:NORTh \n
		Snippet: driver.scenario.df.location.set_north(north = 1.0) \n
		Sets the emitter coordinates. \n
			:param north: float Range: -1e+09 to 1e+09, Unit: m
		"""
		param = Conversions.decimal_value_to_str(north)
		self._core.io.write(f'SCENario:DF:LOCation:NORTh {param}')

	# noinspection PyTypeChecker
	def get_pmode(self) -> enums.PmodeLocation:
		"""SCPI: SCENario:DF:LOCation:PMODe \n
		Snippet: value: enums.PmodeLocation = driver.scenario.df.location.get_pmode() \n
		Sets if the emitter is static or moving. \n
			:return: pmode: STATic| STEPs| MOVing
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:PMODe?')
		return Conversions.str_to_scalar_enum(response, enums.PmodeLocation)

	def set_pmode(self, pmode: enums.PmodeLocation) -> None:
		"""SCPI: SCENario:DF:LOCation:PMODe \n
		Snippet: driver.scenario.df.location.set_pmode(pmode = enums.PmodeLocation.MOVing) \n
		Sets if the emitter is static or moving. \n
			:param pmode: STATic| STEPs| MOVing
		"""
		param = Conversions.enum_scalar_to_str(pmode, enums.PmodeLocation)
		self._core.io.write(f'SCENario:DF:LOCation:PMODe {param}')

	def clone(self) -> 'Location':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Location(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rec:
	"""Rec commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rec", core, parent)

	# noinspection PyTypeChecker
	def get_pmode(self) -> enums.Pmode:
		"""SCPI: SCENario:DF:LOCation:REC:PMODe \n
		Snippet: value: enums.Pmode = driver.scenario.df.location.rec.get_pmode() \n
		Sets if the receiver is static or moving. \n
			:return: pmode: STATic| MOVing
		"""
		response = self._core.io.query_str('SCENario:DF:LOCation:REC:PMODe?')
		return Conversions.str_to_scalar_enum(response, enums.Pmode)

	def set_pmode(self, pmode: enums.Pmode) -> None:
		"""SCPI: SCENario:DF:LOCation:REC:PMODe \n
		Snippet: driver.scenario.df.location.rec.set_pmode(pmode = enums.Pmode.MOVing) \n
		Sets if the receiver is static or moving. \n
			:param pmode: STATic| MOVing
		"""
		param = Conversions.enum_scalar_to_str(pmode, enums.Pmode)
		self._core.io.write(f'SCENario:DF:LOCation:REC:PMODe {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Volatile:
	"""Volatile commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("volatile", core, parent)

	def clear(self) -> None:
		"""SCPI: SCENario:ILCache:VOLatile:CLEar \n
		Snippet: driver.scenario.ilCache.volatile.clear() \n
		Deletes the files from the volatile/repository memory. \n
		"""
		self._core.io.write(f'SCENario:ILCache:VOLatile:CLEar')

	def clear_with_opc(self, opc_timeout_ms: int = -1) -> None:
		"""SCPI: SCENario:ILCache:VOLatile:CLEar \n
		Snippet: driver.scenario.ilCache.volatile.clear_with_opc() \n
		Deletes the files from the volatile/repository memory. \n
		Same as clear, but waits for the operation to complete before continuing further. Use the RsPulseSeq.utilities.opc_timeout_set() to set the timeout value. \n
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SCENario:ILCache:VOLatile:CLEar', opc_timeout_ms)

	def get_valid(self) -> bool:
		"""SCPI: SCENario:ILCache:VOLatile:VALid \n
		Snippet: value: bool = driver.scenario.ilCache.volatile.get_valid() \n
		Queries whether the volatile/repository memory contains a valid signal file. \n
			:return: valid: ON| OFF| 1| 0
		"""
		response = self._core.io.query_str('SCENario:ILCache:VOLatile:VALid?')
		return Conversions.str_to_bool(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Parabolic:
	"""Parabolic commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("parabolic", core, parent)

	def get_diameter(self) -> float:
		"""SCPI: ANTenna:MODel:PARabolic:DIAMeter \n
		Snippet: value: float = driver.antenna.model.parabolic.get_diameter() \n
		Sets the diameter of the parabolic dish antenna. \n
			:return: diameter: float Range: 0.05 to 100, Unit: m
		"""
		response = self._core.io.query_str('ANTenna:MODel:PARabolic:DIAMeter?')
		return Conversions.str_to_float(response)

	def set_diameter(self, diameter: float) -> None:
		"""SCPI: ANTenna:MODel:PARabolic:DIAMeter \n
		Snippet: driver.antenna.model.parabolic.set_diameter(diameter = 1.0) \n
		Sets the diameter of the parabolic dish antenna. \n
			:param diameter: float Range: 0.05 to 100, Unit: m
		"""
		param = Conversions.decimal_value_to_str(diameter)
		self._core.io.write(f'ANTenna:MODel:PARabolic:DIAMeter {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Fm:
	"""Fm commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fm", core, parent)

	def get_deviation(self) -> float:
		"""SCPI: PULSe:MOP:FM:DEViation \n
		Snippet: value: float = driver.pulse.mop.fm.get_deviation() \n
		Sets the modulation deviation. \n
			:return: deviation: float Range: 0.1 to 1e+09, Unit: Hz
		"""
		response = self._core.io.query_str('PULSe:MOP:FM:DEViation?')
		return Conversions.str_to_float(response)

	def set_deviation(self, deviation: float) -> None:
		"""SCPI: PULSe:MOP:FM:DEViation \n
		Snippet: driver.pulse.mop.fm.set_deviation(deviation = 1.0) \n
		Sets the modulation deviation. \n
			:param deviation: float Range: 0.1 to 1e+09, Unit: Hz
		"""
		param = Conversions.decimal_value_to_str(deviation)
		self._core.io.write(f'PULSe:MOP:FM:DEViation {param}')

	def get_frequency(self) -> float:
		"""SCPI: PULSe:MOP:FM:FREQuency \n
		Snippet: value: float = driver.pulse.mop.fm.get_frequency() \n
		Sets the modulation frequency. \n
			:return: frequency: float Range: 0.002 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:FM:FREQuency?')
		return Conversions.str_to_float(response)

	def set_frequency(self, frequency: float) -> None:
		"""SCPI: PULSe:MOP:FM:FREQuency \n
		Snippet: driver.pulse.mop.fm.set_frequency(frequency = 1.0) \n
		Sets the modulation frequency. \n
			:param frequency: float Range: 0.002 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(frequency)
		self._core.io.write(f'PULSe:MOP:FM:FREQuency {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Qam:
	"""Qam commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("qam", core, parent)

	def get_symbol_rate(self) -> float:
		"""SCPI: PULSe:MOP:QAM:SRATe \n
		Snippet: value: float = driver.pulse.mop.qam.get_symbol_rate() \n
		Sets the symbol rate of the modulated signal. \n
			:return: srate: float Range: 1 to 1e+09
		"""
		response = self._core.io.query_str('PULSe:MOP:QAM:SRATe?')
		return Conversions.str_to_float(response)

	def set_symbol_rate(self, srate: float) -> None:
		"""SCPI: PULSe:MOP:QAM:SRATe \n
		Snippet: driver.pulse.mop.qam.set_symbol_rate(srate = 1.0) \n
		Sets the symbol rate of the modulated signal. \n
			:param srate: float Range: 1 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(srate)
		self._core.io.write(f'PULSe:MOP:QAM:SRATe {param}')

	# noinspection PyTypeChecker
	def get_type_py(self) -> enums.QamType:
		"""SCPI: PULSe:MOP:QAM:TYPE \n
		Snippet: value: enums.QamType = driver.pulse.mop.qam.get_type_py() \n
		Selects the QAM type. \n
			:return: type_py: Q16| Q32| Q64| Q128| Q256
		"""
		response = self._core.io.query_str('PULSe:MOP:QAM:TYPE?')
		return Conversions.str_to_scalar_enum(response, enums.QamType)

	def set_type_py(self, type_py: enums.QamType) -> None:
		"""SCPI: PULSe:MOP:QAM:TYPE \n
		Snippet: driver.pulse.mop.qam.set_type_py(type_py = enums.QamType.Q128) \n
		Selects the QAM type. \n
			:param type_py: Q16| Q32| Q64| Q128| Q256
		"""
		param = Conversions.enum_scalar_to_str(type_py, enums.QamType)
		self._core.io.write(f'PULSe:MOP:QAM:TYPE {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HpBw:
	"""HpBw commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("hpBw", core, parent)

	def get_xy(self) -> float:
		"""SCPI: ANTenna:MODel:CUSTom:HPBW:XY \n
		Snippet: value: float = driver.antenna.model.custom.hpBw.get_xy() \n
		Sets the required HPBW of the custom antenna. \n
			:return: xy: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:CUSTom:HPBW:XY?')
		return Conversions.str_to_float(response)

	def set_xy(self, xy: float) -> None:
		"""SCPI: ANTenna:MODel:CUSTom:HPBW:XY \n
		Snippet: driver.antenna.model.custom.hpBw.set_xy(xy = 1.0) \n
		Sets the required HPBW of the custom antenna. \n
			:param xy: float Range: 0.1 to 45
		"""
		param = Conversions.decimal_value_to_str(xy)
		self._core.io.write(f'ANTenna:MODel:CUSTom:HPBW:XY {param}')

	def get_yz(self) -> float:
		"""SCPI: ANTenna:MODel:CUSTom:HPBW:YZ \n
		Snippet: value: float = driver.antenna.model.custom.hpBw.get_yz() \n
		Sets the required HPBW of the custom antenna. \n
			:return: yz: float Range: 0.1 to 45
		"""
		response = self._core.io.query_str('ANTenna:MODel:CUSTom:HPBW:YZ?')
		return Conversions.str_to_float(response)

	def set_yz(self, yz: float) -> None:
		"""SCPI: ANTenna:MODel:CUSTom:HPBW:YZ \n
		Snippet: driver.antenna.model.custom.hpBw.set_yz(yz = 1.0) \n
		Sets the required HPBW of the custom antenna. \n
			:param yz: float Range: 0.1 to 45
		"""
		param = Conversions.decimal_value_to_str(yz)
		self._core.io.write(f'ANTenna:MODel:CUSTom:HPBW:YZ {param}')



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Group:
	"""Group commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("group", core, parent)

	def get_list_py(self) -> str:
		"""SCPI: ASSignment:GROup:LIST \n
		Snippet: value: str = driver.assignment.group.get_list_py() \n
		If interleaving groups are defined, queries the alias names of the unassigned interleaving groups. \n
			:return: list_py: string
		"""
		response = self._core.io.query_str('ASSignment:GROup:LIST?')
		return trim_str_response(response)

	def get_select(self) -> str:
		"""SCPI: ASSignment:GROup:SELect \n
		Snippet: value: str = driver.assignment.group.get_select() \n
		Assigns the selected group to the generator and path selected with the commands method RsPulseSeq.Assignment.Generator.
		select and method RsPulseSeq.Assignment.Generator.Path.select. \n
			:return: select: string
		"""
		response = self._core.io.query_str('ASSignment:GROup:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: ASSignment:GROup:SELect \n
		Snippet: driver.assignment.group.set_select(select = '1') \n
		Assigns the selected group to the generator and path selected with the commands method RsPulseSeq.Assignment.Generator.
		select and method RsPulseSeq.Assignment.Generator.Path.select. \n
			:param select: string
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'ASSignment:GROup:SELect {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Uniform:
	"""Uniform commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("uniform", core, parent)

	def get_maximum(self) -> float:
		"""SCPI: IPM:RANDom:UNIForm:MAXimum \n
		Snippet: value: float = driver.ipm.random.uniform.get_maximum() \n
		Sets the range of the uniform distribution function. \n
			:return: maximum: float Range: -1e+09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:RANDom:UNIForm:MAXimum?')
		return Conversions.str_to_float(response)

	def set_maximum(self, maximum: float) -> None:
		"""SCPI: IPM:RANDom:UNIForm:MAXimum \n
		Snippet: driver.ipm.random.uniform.set_maximum(maximum = 1.0) \n
		Sets the range of the uniform distribution function. \n
			:param maximum: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(maximum)
		self._core.io.write(f'IPM:RANDom:UNIForm:MAXimum {param}')

	def get_minimum(self) -> float:
		"""SCPI: IPM:RANDom:UNIForm:MINimum \n
		Snippet: value: float = driver.ipm.random.uniform.get_minimum() \n
		Sets the range of the uniform distribution function. \n
			:return: minimum: No help available
		"""
		response = self._core.io.query_str('IPM:RANDom:UNIForm:MINimum?')
		return Conversions.str_to_float(response)

	def set_minimum(self, minimum: float) -> None:
		"""SCPI: IPM:RANDom:UNIForm:MINimum \n
		Snippet: driver.ipm.random.uniform.set_minimum(minimum = 1.0) \n
		Sets the range of the uniform distribution function. \n
			:param minimum: float Range: -1e+09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(minimum)
		self._core.io.write(f'IPM:RANDom:UNIForm:MINimum {param}')

	def get_step(self) -> float:
		"""SCPI: IPM:RANDom:UNIForm:STEP \n
		Snippet: value: float = driver.ipm.random.uniform.get_step() \n
		Sets the granularity of the uniform distribution function. \n
			:return: step: float Range: 1e-09 to 1e+09
		"""
		response = self._core.io.query_str('IPM:RANDom:UNIForm:STEP?')
		return Conversions.str_to_float(response)

	def set_step(self, step: float) -> None:
		"""SCPI: IPM:RANDom:UNIForm:STEP \n
		Snippet: driver.ipm.random.uniform.set_step(step = 1.0) \n
		Sets the granularity of the uniform distribution function. \n
			:param step: float Range: 1e-09 to 1e+09
		"""
		param = Conversions.decimal_value_to_str(step)
		self._core.io.write(f'IPM:RANDom:UNIForm:STEP {param}')



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Direction:
	"""Direction commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("direction", core, parent)

	def get_pitch(self) -> float:
		"""SCPI: SCENario:CEMit:DIRection:PITCh \n
		Snippet: value: float = driver.scenario.cemit.direction.get_pitch() \n
		Sets the pitch. \n
			:return: pitch: float Range: -90 to 90, Unit: grad
		"""
		response = self._core.io.query_str('SCENario:CEMit:DIRection:PITCh?')
		return Conversions.str_to_float(response)

	def set_pitch(self, pitch: float) -> None:
		"""SCPI: SCENario:CEMit:DIRection:PITCh \n
		Snippet: driver.scenario.cemit.direction.set_pitch(pitch = 1.0) \n
		Sets the pitch. \n
			:param pitch: float Range: -90 to 90, Unit: grad
		"""
		param = Conversions.decimal_value_to_str(pitch)
		self._core.io.write(f'SCENario:CEMit:DIRection:PITCh {param}')

	def get_roll(self) -> float:
		"""SCPI: SCENario:CEMit:DIRection:ROLL \n
		Snippet: value: float = driver.scenario.cemit.direction.get_roll() \n
		Sets the roll. \n
			:return: roll: float Range: 0 to 360
		"""
		response = self._core.io.query_str('SCENario:CEMit:DIRection:ROLL?')
		return Conversions.str_to_float(response)

	def set_roll(self, roll: float) -> None:
		"""SCPI: SCENario:CEMit:DIRection:ROLL \n
		Snippet: driver.scenario.cemit.direction.set_roll(roll = 1.0) \n
		Sets the roll. \n
			:param roll: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(roll)
		self._core.io.write(f'SCENario:CEMit:DIRection:ROLL {param}')

	def get_yaw(self) -> float:
		"""SCPI: SCENario:CEMit:DIRection:YAW \n
		Snippet: value: float = driver.scenario.cemit.direction.get_yaw() \n
		Sets the yaw. \n
			:return: yaw: float Range: 0 to 360
		"""
		response = self._core.io.query_str('SCENario:CEMit:DIRection:YAW?')
		return Conversions.str_to_float(response)

	def set_yaw(self, yaw: float) -> None:
		"""SCPI: SCENario:CEMit:DIRection:YAW \n
		Snippet: driver.scenario.cemit.direction.set_yaw(yaw = 1.0) \n
		Sets the yaw. \n
			:param yaw: float Range: 0 to 360
		"""
		param = Conversions.decimal_value_to_str(yaw)
		self._core.io.write(f'SCENario:CEMit:DIRection:YAW {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pstep:
	"""Pstep commands group definition. 4 total commands, 1 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pstep", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._cmd_group)
		return self._add

	def get_count(self) -> float:
		"""SCPI: SCENario:LOCalized:LOCation:PSTep:COUNt \n
		Snippet: value: float = driver.scenario.localized.location.pstep.get_count() \n
		Queries the number of existing items. \n
			:return: count: integer
		"""
		response = self._core.io.query_str('SCENario:LOCalized:LOCation:PSTep:COUNt?')
		return Conversions.str_to_float(response)

	def delete(self, delete: float) -> None:
		"""SCPI: SCENario:LOCalized:LOCation:PSTep:DELete \n
		Snippet: driver.scenario.localized.location.pstep.delete(delete = 1.0) \n
		Deletes the particular item. \n
			:param delete: float
		"""
		param = Conversions.decimal_value_to_str(delete)
		self._core.io.write(f'SCENario:LOCalized:LOCation:PSTep:DELete {param}')

	def get_select(self) -> float:
		"""SCPI: SCENario:LOCalized:LOCation:PSTep:SELect \n
		Snippet: value: float = driver.scenario.localized.location.pstep.get_select() \n
		Selects the item to which the subsequent commands apply. \n
			:return: select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		response = self._core.io.query_str('SCENario:LOCalized:LOCation:PSTep:SELect?')
		return Conversions.str_to_float(response)

	def set_select(self, select: float) -> None:
		"""SCPI: SCENario:LOCalized:LOCation:PSTep:SELect \n
		Snippet: driver.scenario.localized.location.pstep.set_select(select = 1.0) \n
		Selects the item to which the subsequent commands apply. \n
			:param select: float Item number within the range 1 to ...:COUNt. For example, method RsPulseSeq.Sequence.Item.count. Range: 1 to 4096
		"""
		param = Conversions.decimal_value_to_str(select)
		self._core.io.write(f'SCENario:LOCalized:LOCation:PSTep:SELect {param}')

	def clone(self) -> 'Pstep':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Pstep(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Circular:
	"""Circular commands group definition. 3 total commands, 0 Subgroups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("circular", core, parent)

	def get_distance(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:DISTance \n
		Snippet: value: float = driver.antenna.model.carray.circular.get_distance() \n
		Sets the spacing between the elements of the array antenna. \n
			:return: distance: No help available
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:CIRCular:DISTance?')
		return Conversions.str_to_float(response)

	def set_distance(self, distance: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:DISTance \n
		Snippet: driver.antenna.model.carray.circular.set_distance(distance = 1.0) \n
		Sets the spacing between the elements of the array antenna. \n
			:param distance: float Range: 0.0001 to 1
		"""
		param = Conversions.decimal_value_to_str(distance)
		self._core.io.write(f'ANTenna:MODel:CARRay:CIRCular:DISTance {param}')

	# noinspection PyTypeChecker
	def get_lattice(self) -> enums.Lattice:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:LATTice \n
		Snippet: value: enums.Lattice = driver.antenna.model.carray.circular.get_lattice() \n
		Sets the lattice. \n
			:return: lattice: RECTangular| TRIangular
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:CIRCular:LATTice?')
		return Conversions.str_to_scalar_enum(response, enums.Lattice)

	def set_lattice(self, lattice: enums.Lattice) -> None:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:LATTice \n
		Snippet: driver.antenna.model.carray.circular.set_lattice(lattice = enums.Lattice.RECTangular) \n
		Sets the lattice. \n
			:param lattice: RECTangular| TRIangular
		"""
		param = Conversions.enum_scalar_to_str(lattice, enums.Lattice)
		self._core.io.write(f'ANTenna:MODel:CARRay:CIRCular:LATTice {param}')

	def get_radius(self) -> float:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:RADius \n
		Snippet: value: float = driver.antenna.model.carray.circular.get_radius() \n
		Set the radius of the circular phased array antenna. \n
			:return: radius: float Range: 1 to 50
		"""
		response = self._core.io.query_str('ANTenna:MODel:CARRay:CIRCular:RADius?')
		return Conversions.str_to_float(response)

	def set_radius(self, radius: float) -> None:
		"""SCPI: ANTenna:MODel:CARRay:CIRCular:RADius \n
		Snippet: driver.antenna.model.carray.circular.set_radius(radius = 1.0) \n
		Set the radius of the circular phased array antenna. \n
			:param radius: float Range: 1 to 50
		"""
		param = Conversions.decimal_value_to_str(radius)
		self._core.io.write(f'ANTenna:MODel:CARRay:CIRCular:RADius {param}')
